"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StopPidMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start stop a PID"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    pid: builtins.int
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pid", b"pid"]) -> None: ...

global___StopPidMsg = StopPidMsg

@typing_extensions.final
class CheckPidMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start check the status of a PID"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    pid: builtins.int
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pid", b"pid"]) -> None: ...

global___CheckPidMsg = CheckPidMsg

@typing_extensions.final
class StartSparkServerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific Spark server"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSparkServerMsg = StartSparkServerMsg

@typing_extensions.final
class StopSparkServerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific Spark server"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSparkServerMsg = StopSparkServerMsg

@typing_extensions.final
class StartSparkServersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the spark servers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSparkServersMsg = StartSparkServersMsg

@typing_extensions.final
class StopSparkServersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the spark servers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSparkServersMsg = StopSparkServersMsg

@typing_extensions.final
class GetExecutionTimeSeriesDataMsg(google.protobuf.message.Message):
    """Message that the client sends to get the flask logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    minutes: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        minutes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet", "minutes", b"minutes"]) -> None: ...

global___GetExecutionTimeSeriesDataMsg = GetExecutionTimeSeriesDataMsg

@typing_extensions.final
class EmulationMetricsTimeSeriesDTO(google.protobuf.message.Message):
    """DTO with data of an emulation, extracted from the Kafka container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_METRICS_FIELD_NUMBER: builtins.int
    AGGREGATED_DOCKER_STATS_FIELD_NUMBER: builtins.int
    DOCKER_HOST_STATS_FIELD_NUMBER: builtins.int
    HOST_METRICS_FIELD_NUMBER: builtins.int
    AGGREGATED_HOST_METRICS_FIELD_NUMBER: builtins.int
    DEFENDER_ACTIONS_FIELD_NUMBER: builtins.int
    ATTACKER_ACTIONS_FIELD_NUMBER: builtins.int
    AGG_SNORT_IDS_METRICS_FIELD_NUMBER: builtins.int
    EMULATION_ID_FIELD_NUMBER: builtins.int
    OSSEC_HOST_ALERT_COUNTERS_FIELD_NUMBER: builtins.int
    AGGREGATED_OSSEC_HOST_ALERT_COUNTERS_FIELD_NUMBER: builtins.int
    OPENFLOW_FLOW_STATS_FIELD_NUMBER: builtins.int
    OPENFLOW_PORT_STATS_FIELD_NUMBER: builtins.int
    AVG_OPENFLOW_FLOW_STATS_FIELD_NUMBER: builtins.int
    AVG_OPENFLOW_PORT_STATS_FIELD_NUMBER: builtins.int
    OPENFLOW_FLOW_METRICS_PER_SWITCH_FIELD_NUMBER: builtins.int
    OPENFLOW_PORT_METRICS_PER_SWITCH_FIELD_NUMBER: builtins.int
    OPENFLOW_FLOW_AVG_METRICS_PER_SWITCH_FIELD_NUMBER: builtins.int
    OPENFLOW_PORT_AVG_METRICS_PER_SWITCH_FIELD_NUMBER: builtins.int
    AGG_OPENFLOW_FLOW_METRICS_PER_SWITCH_FIELD_NUMBER: builtins.int
    AGG_OPENFLOW_FLOW_STATS_FIELD_NUMBER: builtins.int
    AGG_SNORT_IDS_RULE_METRICS_FIELD_NUMBER: builtins.int
    SNORT_IDS_IP_METRICS_FIELD_NUMBER: builtins.int
    SNORT_RULE_METRICS_PER_IDS_FIELD_NUMBER: builtins.int
    SNORT_ALERT_METRICS_PER_IDS_FIELD_NUMBER: builtins.int
    @property
    def client_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClientPopulationMetricsDTO]: ...
    @property
    def aggregated_docker_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerStatsDTO]: ...
    @property
    def docker_host_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerStatsDict]: ...
    @property
    def host_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostMetricsDict]: ...
    @property
    def aggregated_host_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostMetricsDataDTO]: ...
    @property
    def defender_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmulationDefenderActionDTO]: ...
    @property
    def attacker_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmulationAttackerActionDTO]: ...
    @property
    def agg_snort_ids_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsAlertCountersDTO]: ...
    emulation_id: builtins.int
    @property
    def ossec_host_alert_counters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OSSECIdsAlertCountersDict]: ...
    @property
    def aggregated_ossec_host_alert_counters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OSSECIdsAlertCountersDTO]: ...
    @property
    def openflow_flow_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowStatisticDTO]: ...
    @property
    def openflow_port_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortStatisticDTO]: ...
    @property
    def avg_openflow_flow_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvgFlowStatisticDTO]: ...
    @property
    def avg_openflow_port_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvgPortStatisticDTO]: ...
    @property
    def openflow_flow_metrics_per_switch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowStatisticDict]: ...
    @property
    def openflow_port_metrics_per_switch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortStatisticDict]: ...
    @property
    def openflow_flow_avg_metrics_per_switch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvgFlowStatisticDict]: ...
    @property
    def openflow_port_avg_metrics_per_switch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvgPortStatisticDict]: ...
    @property
    def agg_openflow_flow_metrics_per_switch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AggFlowStatisticDict]: ...
    @property
    def agg_openflow_flow_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AggFlowStatisticDTO]: ...
    @property
    def agg_snort_ids_rule_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsRuleCountersDTO]: ...
    @property
    def snort_ids_ip_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsIpAlertCountersDict]: ...
    @property
    def snort_rule_metrics_per_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsRuleCountersDict]: ...
    @property
    def snort_alert_metrics_per_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsAlertCountersDict]: ...
    def __init__(
        self,
        *,
        client_metrics: collections.abc.Iterable[global___ClientPopulationMetricsDTO] | None = ...,
        aggregated_docker_stats: collections.abc.Iterable[global___DockerStatsDTO] | None = ...,
        docker_host_stats: collections.abc.Iterable[global___DockerStatsDict] | None = ...,
        host_metrics: collections.abc.Iterable[global___HostMetricsDict] | None = ...,
        aggregated_host_metrics: collections.abc.Iterable[global___HostMetricsDataDTO] | None = ...,
        defender_actions: collections.abc.Iterable[global___EmulationDefenderActionDTO] | None = ...,
        attacker_actions: collections.abc.Iterable[global___EmulationAttackerActionDTO] | None = ...,
        agg_snort_ids_metrics: collections.abc.Iterable[global___SnortIdsAlertCountersDTO] | None = ...,
        emulation_id: builtins.int = ...,
        ossec_host_alert_counters: collections.abc.Iterable[global___OSSECIdsAlertCountersDict] | None = ...,
        aggregated_ossec_host_alert_counters: collections.abc.Iterable[global___OSSECIdsAlertCountersDTO] | None = ...,
        openflow_flow_stats: collections.abc.Iterable[global___FlowStatisticDTO] | None = ...,
        openflow_port_stats: collections.abc.Iterable[global___PortStatisticDTO] | None = ...,
        avg_openflow_flow_stats: collections.abc.Iterable[global___AvgFlowStatisticDTO] | None = ...,
        avg_openflow_port_stats: collections.abc.Iterable[global___AvgPortStatisticDTO] | None = ...,
        openflow_flow_metrics_per_switch: collections.abc.Iterable[global___FlowStatisticDict] | None = ...,
        openflow_port_metrics_per_switch: collections.abc.Iterable[global___PortStatisticDict] | None = ...,
        openflow_flow_avg_metrics_per_switch: collections.abc.Iterable[global___AvgFlowStatisticDict] | None = ...,
        openflow_port_avg_metrics_per_switch: collections.abc.Iterable[global___AvgPortStatisticDict] | None = ...,
        agg_openflow_flow_metrics_per_switch: collections.abc.Iterable[global___AggFlowStatisticDict] | None = ...,
        agg_openflow_flow_stats: collections.abc.Iterable[global___AggFlowStatisticDTO] | None = ...,
        agg_snort_ids_rule_metrics: collections.abc.Iterable[global___SnortIdsRuleCountersDTO] | None = ...,
        snort_ids_ip_metrics: collections.abc.Iterable[global___SnortIdsIpAlertCountersDict] | None = ...,
        snort_rule_metrics_per_ids: collections.abc.Iterable[global___SnortIdsRuleCountersDict] | None = ...,
        snort_alert_metrics_per_ids: collections.abc.Iterable[global___SnortIdsAlertCountersDict] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agg_openflow_flow_metrics_per_switch", b"agg_openflow_flow_metrics_per_switch", "agg_openflow_flow_stats", b"agg_openflow_flow_stats", "agg_snort_ids_metrics", b"agg_snort_ids_metrics", "agg_snort_ids_rule_metrics", b"agg_snort_ids_rule_metrics", "aggregated_docker_stats", b"aggregated_docker_stats", "aggregated_host_metrics", b"aggregated_host_metrics", "aggregated_ossec_host_alert_counters", b"aggregated_ossec_host_alert_counters", "attacker_actions", b"attacker_actions", "avg_openflow_flow_stats", b"avg_openflow_flow_stats", "avg_openflow_port_stats", b"avg_openflow_port_stats", "client_metrics", b"client_metrics", "defender_actions", b"defender_actions", "docker_host_stats", b"docker_host_stats", "emulation_id", b"emulation_id", "host_metrics", b"host_metrics", "openflow_flow_avg_metrics_per_switch", b"openflow_flow_avg_metrics_per_switch", "openflow_flow_metrics_per_switch", b"openflow_flow_metrics_per_switch", "openflow_flow_stats", b"openflow_flow_stats", "openflow_port_avg_metrics_per_switch", b"openflow_port_avg_metrics_per_switch", "openflow_port_metrics_per_switch", b"openflow_port_metrics_per_switch", "openflow_port_stats", b"openflow_port_stats", "ossec_host_alert_counters", b"ossec_host_alert_counters", "snort_alert_metrics_per_ids", b"snort_alert_metrics_per_ids", "snort_ids_ip_metrics", b"snort_ids_ip_metrics", "snort_rule_metrics_per_ids", b"snort_rule_metrics_per_ids"]) -> None: ...

global___EmulationMetricsTimeSeriesDTO = EmulationMetricsTimeSeriesDTO

@typing_extensions.final
class AvgPortStatisticDict(google.protobuf.message.Message):
    """Dict which maps a string key to a AvgPortStatisticDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvgPortStatisticDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___AvgPortStatisticDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___AvgPortStatisticDict = AvgPortStatisticDict

@typing_extensions.final
class AggFlowStatisticDict(google.protobuf.message.Message):
    """Dict which maps a string key to an AggFlowStatisticDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AggFlowStatisticDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___AggFlowStatisticDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___AggFlowStatisticDict = AggFlowStatisticDict

@typing_extensions.final
class AvgFlowStatisticDict(google.protobuf.message.Message):
    """Dict which maps a string key to an AvgFlowStatisticDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvgFlowStatisticDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___AvgFlowStatisticDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___AvgFlowStatisticDict = AvgFlowStatisticDict

@typing_extensions.final
class PortStatisticDict(google.protobuf.message.Message):
    """Dict which maps a string key to a PortStatistic"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortStatisticDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___PortStatisticDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___PortStatisticDict = PortStatisticDict

@typing_extensions.final
class FlowStatisticDict(google.protobuf.message.Message):
    """Dict which maps a string key to a FlowStatisticDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowStatisticDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___FlowStatisticDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___FlowStatisticDict = FlowStatisticDict

@typing_extensions.final
class OSSECIdsAlertCountersDict(google.protobuf.message.Message):
    """Dict which maps a string key to a OSSECIdsAlertCountersDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OSSECIdsAlertCountersDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___OSSECIdsAlertCountersDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___OSSECIdsAlertCountersDict = OSSECIdsAlertCountersDict

@typing_extensions.final
class HostMetricsDict(google.protobuf.message.Message):
    """Dict which maps a string key to a HostMetricsDataDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostMetricsDataDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___HostMetricsDataDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___HostMetricsDict = HostMetricsDict

@typing_extensions.final
class DockerStatsDict(google.protobuf.message.Message):
    """Dict which maps a string key to a DockerStatsDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerStatsDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___DockerStatsDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___DockerStatsDict = DockerStatsDict

@typing_extensions.final
class AvgPortStatisticDTO(google.protobuf.message.Message):
    """DTO with data about avg flow statistics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATAPATH_ID_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_PACKETS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_BYTES_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_ERRORS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_TRANSMITTED_PACKETS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_TRANSMITTED_BYTES_FIELD_NUMBER: builtins.int
    TOTAL_NUM_TRANSMITTED_ERRORS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_DROPPED_FIELD_NUMBER: builtins.int
    TOTAL_NUM_TRANSMITTED_DROPPED_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_FRAME_ERRORS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_OVERRUN_ERRORS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_RECEIVED_CRC_ERRORS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_COLLISIONS_FIELD_NUMBER: builtins.int
    AVG_DURATION_NANOSECONDS_FIELD_NUMBER: builtins.int
    AVG_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    datapath_id: builtins.str
    total_num_received_packets: builtins.int
    total_num_received_bytes: builtins.int
    total_num_received_errors: builtins.int
    total_num_transmitted_packets: builtins.int
    total_num_transmitted_bytes: builtins.int
    total_num_transmitted_errors: builtins.int
    total_num_received_dropped: builtins.int
    total_num_transmitted_dropped: builtins.int
    total_num_received_frame_errors: builtins.int
    total_num_received_overrun_errors: builtins.int
    total_num_received_crc_errors: builtins.int
    total_num_collisions: builtins.int
    avg_duration_nanoseconds: builtins.int
    avg_duration_seconds: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        datapath_id: builtins.str = ...,
        total_num_received_packets: builtins.int = ...,
        total_num_received_bytes: builtins.int = ...,
        total_num_received_errors: builtins.int = ...,
        total_num_transmitted_packets: builtins.int = ...,
        total_num_transmitted_bytes: builtins.int = ...,
        total_num_transmitted_errors: builtins.int = ...,
        total_num_received_dropped: builtins.int = ...,
        total_num_transmitted_dropped: builtins.int = ...,
        total_num_received_frame_errors: builtins.int = ...,
        total_num_received_overrun_errors: builtins.int = ...,
        total_num_received_crc_errors: builtins.int = ...,
        total_num_collisions: builtins.int = ...,
        avg_duration_nanoseconds: builtins.int = ...,
        avg_duration_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avg_duration_nanoseconds", b"avg_duration_nanoseconds", "avg_duration_seconds", b"avg_duration_seconds", "datapath_id", b"datapath_id", "timestamp", b"timestamp", "total_num_collisions", b"total_num_collisions", "total_num_received_bytes", b"total_num_received_bytes", "total_num_received_crc_errors", b"total_num_received_crc_errors", "total_num_received_dropped", b"total_num_received_dropped", "total_num_received_errors", b"total_num_received_errors", "total_num_received_frame_errors", b"total_num_received_frame_errors", "total_num_received_overrun_errors", b"total_num_received_overrun_errors", "total_num_received_packets", b"total_num_received_packets", "total_num_transmitted_bytes", b"total_num_transmitted_bytes", "total_num_transmitted_dropped", b"total_num_transmitted_dropped", "total_num_transmitted_errors", b"total_num_transmitted_errors", "total_num_transmitted_packets", b"total_num_transmitted_packets"]) -> None: ...

global___AvgPortStatisticDTO = AvgPortStatisticDTO

@typing_extensions.final
class AvgFlowStatisticDTO(google.protobuf.message.Message):
    """DTO with data about avg flow statistics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATAPATH_ID_FIELD_NUMBER: builtins.int
    TOTAL_NUM_PACKETS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_BYTES_FIELD_NUMBER: builtins.int
    AVG_DURATION_NANOSECONDS_FIELD_NUMBER: builtins.int
    AVG_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    AVG_HARD_TIMEOUT_FIELD_NUMBER: builtins.int
    AVG_IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    AVG_PRIORITY_FIELD_NUMBER: builtins.int
    AVG_COOKIE_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    datapath_id: builtins.str
    total_num_packets: builtins.int
    total_num_bytes: builtins.int
    avg_duration_nanoseconds: builtins.int
    avg_duration_seconds: builtins.int
    avg_hard_timeout: builtins.int
    avg_idle_timeout: builtins.int
    avg_priority: builtins.int
    avg_cookie: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        datapath_id: builtins.str = ...,
        total_num_packets: builtins.int = ...,
        total_num_bytes: builtins.int = ...,
        avg_duration_nanoseconds: builtins.int = ...,
        avg_duration_seconds: builtins.int = ...,
        avg_hard_timeout: builtins.int = ...,
        avg_idle_timeout: builtins.int = ...,
        avg_priority: builtins.int = ...,
        avg_cookie: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avg_cookie", b"avg_cookie", "avg_duration_nanoseconds", b"avg_duration_nanoseconds", "avg_duration_seconds", b"avg_duration_seconds", "avg_hard_timeout", b"avg_hard_timeout", "avg_idle_timeout", b"avg_idle_timeout", "avg_priority", b"avg_priority", "datapath_id", b"datapath_id", "timestamp", b"timestamp", "total_num_bytes", b"total_num_bytes", "total_num_packets", b"total_num_packets"]) -> None: ...

global___AvgFlowStatisticDTO = AvgFlowStatisticDTO

@typing_extensions.final
class AggFlowStatisticDTO(google.protobuf.message.Message):
    """DTO with data about agg flow statistics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATAPATH_ID_FIELD_NUMBER: builtins.int
    TOTAL_NUM_PACKETS_FIELD_NUMBER: builtins.int
    TOTAL_NUM_BYTES_FIELD_NUMBER: builtins.int
    TOTAL_NUM_FLOWS_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    datapath_id: builtins.str
    total_num_packets: builtins.int
    total_num_bytes: builtins.int
    total_num_flows: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        datapath_id: builtins.str = ...,
        total_num_packets: builtins.int = ...,
        total_num_bytes: builtins.int = ...,
        total_num_flows: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["datapath_id", b"datapath_id", "timestamp", b"timestamp", "total_num_bytes", b"total_num_bytes", "total_num_flows", b"total_num_flows", "total_num_packets", b"total_num_packets"]) -> None: ...

global___AggFlowStatisticDTO = AggFlowStatisticDTO

@typing_extensions.final
class PortStatisticDTO(google.protobuf.message.Message):
    """DTO with data about port statistics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATAPATH_ID_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_PACKETS_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_BYTES_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_ERRORS_FIELD_NUMBER: builtins.int
    NUM_TRANSMITTED_PACKETS_FIELD_NUMBER: builtins.int
    NUM_TRANSMITTED_BYTES_FIELD_NUMBER: builtins.int
    NUM_TRANSMITTED_ERRORS_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_DROPPED_FIELD_NUMBER: builtins.int
    NUM_TRANSMITTED_DROPPED_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_FRAME_ERRORS_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_OVERRUN_ERRORS_FIELD_NUMBER: builtins.int
    NUM_RECEIVED_CRC_ERRORS_FIELD_NUMBER: builtins.int
    NUM_COLLISIONS_FIELD_NUMBER: builtins.int
    DURATION_NANOSECONDS_FIELD_NUMBER: builtins.int
    DURATION_SECONDS_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    datapath_id: builtins.str
    port: builtins.int
    num_received_packets: builtins.int
    num_received_bytes: builtins.int
    num_received_errors: builtins.int
    num_transmitted_packets: builtins.int
    num_transmitted_bytes: builtins.int
    num_transmitted_errors: builtins.int
    num_received_dropped: builtins.int
    num_transmitted_dropped: builtins.int
    num_received_frame_errors: builtins.int
    num_received_overrun_errors: builtins.int
    num_received_crc_errors: builtins.int
    num_collisions: builtins.int
    duration_nanoseconds: builtins.int
    duration_seconds: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        datapath_id: builtins.str = ...,
        port: builtins.int = ...,
        num_received_packets: builtins.int = ...,
        num_received_bytes: builtins.int = ...,
        num_received_errors: builtins.int = ...,
        num_transmitted_packets: builtins.int = ...,
        num_transmitted_bytes: builtins.int = ...,
        num_transmitted_errors: builtins.int = ...,
        num_received_dropped: builtins.int = ...,
        num_transmitted_dropped: builtins.int = ...,
        num_received_frame_errors: builtins.int = ...,
        num_received_overrun_errors: builtins.int = ...,
        num_received_crc_errors: builtins.int = ...,
        num_collisions: builtins.int = ...,
        duration_nanoseconds: builtins.int = ...,
        duration_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["datapath_id", b"datapath_id", "duration_nanoseconds", b"duration_nanoseconds", "duration_seconds", b"duration_seconds", "num_collisions", b"num_collisions", "num_received_bytes", b"num_received_bytes", "num_received_crc_errors", b"num_received_crc_errors", "num_received_dropped", b"num_received_dropped", "num_received_errors", b"num_received_errors", "num_received_frame_errors", b"num_received_frame_errors", "num_received_overrun_errors", b"num_received_overrun_errors", "num_received_packets", b"num_received_packets", "num_transmitted_bytes", b"num_transmitted_bytes", "num_transmitted_dropped", b"num_transmitted_dropped", "num_transmitted_errors", b"num_transmitted_errors", "num_transmitted_packets", b"num_transmitted_packets", "port", b"port", "timestamp", b"timestamp"]) -> None: ...

global___PortStatisticDTO = PortStatisticDTO

@typing_extensions.final
class FlowStatisticDTO(google.protobuf.message.Message):
    """DTO with data about flow statistics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATAPATH_ID_FIELD_NUMBER: builtins.int
    IN_PORT_FIELD_NUMBER: builtins.int
    OUT_PORT_FIELD_NUMBER: builtins.int
    DST_MAC_ADDRESS_FIELD_NUMBER: builtins.int
    NUM_PACKETS_FIELD_NUMBER: builtins.int
    NUM_BYTES_FIELD_NUMBER: builtins.int
    DURATION_NANOSECONDS_FIELD_NUMBER: builtins.int
    DURATION_SECONDS_FIELD_NUMBER: builtins.int
    HARD_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    COOKIE_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    datapath_id: builtins.str
    in_port: builtins.str
    out_port: builtins.str
    dst_mac_address: builtins.str
    num_packets: builtins.int
    num_bytes: builtins.int
    duration_nanoseconds: builtins.int
    duration_seconds: builtins.int
    hard_timeout: builtins.int
    idle_timeout: builtins.int
    priority: builtins.int
    cookie: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        datapath_id: builtins.str = ...,
        in_port: builtins.str = ...,
        out_port: builtins.str = ...,
        dst_mac_address: builtins.str = ...,
        num_packets: builtins.int = ...,
        num_bytes: builtins.int = ...,
        duration_nanoseconds: builtins.int = ...,
        duration_seconds: builtins.int = ...,
        hard_timeout: builtins.int = ...,
        idle_timeout: builtins.int = ...,
        priority: builtins.int = ...,
        cookie: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cookie", b"cookie", "datapath_id", b"datapath_id", "dst_mac_address", b"dst_mac_address", "duration_nanoseconds", b"duration_nanoseconds", "duration_seconds", b"duration_seconds", "hard_timeout", b"hard_timeout", "idle_timeout", b"idle_timeout", "in_port", b"in_port", "num_bytes", b"num_bytes", "num_packets", b"num_packets", "out_port", b"out_port", "priority", b"priority", "timestamp", b"timestamp"]) -> None: ...

global___FlowStatisticDTO = FlowStatisticDTO

@typing_extensions.final
class OSSECIdsAlertCountersDTO(google.protobuf.message.Message):
    """DTO with data about OSSEC IDS alerts"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_ALERTS_FIELD_NUMBER: builtins.int
    GROUP_ALERTS_FIELD_NUMBER: builtins.int
    SEVERE_ALERTS_FIELD_NUMBER: builtins.int
    WARNING_ALERTS_FIELD_NUMBER: builtins.int
    TOTAL_ALERTS_FIELD_NUMBER: builtins.int
    ALERTS_WEIGHTED_BY_LEVEL_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    @property
    def level_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def group_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    severe_alerts: builtins.int
    warning_alerts: builtins.int
    total_alerts: builtins.int
    alerts_weighted_by_level: builtins.float
    ip: builtins.str
    ts: builtins.float
    def __init__(
        self,
        *,
        level_alerts: collections.abc.Iterable[builtins.int] | None = ...,
        group_alerts: collections.abc.Iterable[builtins.int] | None = ...,
        severe_alerts: builtins.int = ...,
        warning_alerts: builtins.int = ...,
        total_alerts: builtins.int = ...,
        alerts_weighted_by_level: builtins.float = ...,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts_weighted_by_level", b"alerts_weighted_by_level", "group_alerts", b"group_alerts", "ip", b"ip", "level_alerts", b"level_alerts", "severe_alerts", b"severe_alerts", "total_alerts", b"total_alerts", "ts", b"ts", "warning_alerts", b"warning_alerts"]) -> None: ...

global___OSSECIdsAlertCountersDTO = OSSECIdsAlertCountersDTO

@typing_extensions.final
class SnortIdsAlertCountersDTO(google.protobuf.message.Message):
    """DTO with data about Snort alerts"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_ALERTS_FIELD_NUMBER: builtins.int
    CLASS_ALERTS_FIELD_NUMBER: builtins.int
    SEVERE_ALERTS_FIELD_NUMBER: builtins.int
    WARNING_ALERTS_FIELD_NUMBER: builtins.int
    ALERTS_WEIGHTED_BY_PRIORITY_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    @property
    def priority_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def class_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    severe_alerts: builtins.int
    warning_alerts: builtins.int
    alerts_weighted_by_priority: builtins.float
    ip: builtins.str
    ts: builtins.float
    def __init__(
        self,
        *,
        priority_alerts: collections.abc.Iterable[builtins.int] | None = ...,
        class_alerts: collections.abc.Iterable[builtins.int] | None = ...,
        severe_alerts: builtins.int = ...,
        warning_alerts: builtins.int = ...,
        alerts_weighted_by_priority: builtins.float = ...,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts_weighted_by_priority", b"alerts_weighted_by_priority", "class_alerts", b"class_alerts", "ip", b"ip", "priority_alerts", b"priority_alerts", "severe_alerts", b"severe_alerts", "ts", b"ts", "warning_alerts", b"warning_alerts"]) -> None: ...

global___SnortIdsAlertCountersDTO = SnortIdsAlertCountersDTO

@typing_extensions.final
class SnortIdsIpAlertCountersDict(google.protobuf.message.Message):
    """Dict which maps a string key to a SnortIdsIpAlertCountersDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsIpAlertCountersDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___SnortIdsIpAlertCountersDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___SnortIdsIpAlertCountersDict = SnortIdsIpAlertCountersDict

@typing_extensions.final
class SnortIdsAlertCountersDict(google.protobuf.message.Message):
    """Dict which maps a string key to a SnortIdsAlertCountersDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsAlertCountersDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___SnortIdsAlertCountersDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___SnortIdsAlertCountersDict = SnortIdsAlertCountersDict

@typing_extensions.final
class SnortIdsRuleCountersDict(google.protobuf.message.Message):
    """Dict which maps a string key to a SnortIdsRuleCountersDTO"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DTOS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def dtos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsRuleCountersDTO]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        dtos: collections.abc.Iterable[global___SnortIdsRuleCountersDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dtos", b"dtos", "key", b"key"]) -> None: ...

global___SnortIdsRuleCountersDict = SnortIdsRuleCountersDict

@typing_extensions.final
class SnortIdsIpAlertCountersDTO(google.protobuf.message.Message):
    """DTO with data about Snort alerts"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_ALERTS_FIELD_NUMBER: builtins.int
    CLASS_ALERTS_FIELD_NUMBER: builtins.int
    SEVERE_ALERTS_FIELD_NUMBER: builtins.int
    WARNING_ALERTS_FIELD_NUMBER: builtins.int
    ALERTS_WEIGHTED_BY_PRIORITY_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    ALERT_IP_FIELD_NUMBER: builtins.int
    @property
    def priority_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def class_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    severe_alerts: builtins.int
    warning_alerts: builtins.int
    alerts_weighted_by_priority: builtins.float
    ip: builtins.str
    ts: builtins.float
    alert_ip: builtins.str
    def __init__(
        self,
        *,
        priority_alerts: collections.abc.Iterable[builtins.int] | None = ...,
        class_alerts: collections.abc.Iterable[builtins.int] | None = ...,
        severe_alerts: builtins.int = ...,
        warning_alerts: builtins.int = ...,
        alerts_weighted_by_priority: builtins.float = ...,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
        alert_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alert_ip", b"alert_ip", "alerts_weighted_by_priority", b"alerts_weighted_by_priority", "class_alerts", b"class_alerts", "ip", b"ip", "priority_alerts", b"priority_alerts", "severe_alerts", b"severe_alerts", "ts", b"ts", "warning_alerts", b"warning_alerts"]) -> None: ...

global___SnortIdsIpAlertCountersDTO = SnortIdsIpAlertCountersDTO

@typing_extensions.final
class SnortIdsRuleCountersDTO(google.protobuf.message.Message):
    """DTO with data about Snort rule alerts"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_IDS_FIELD_NUMBER: builtins.int
    RULE_ALERT_COUNTS_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    @property
    def rule_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def rule_alert_counts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    ip: builtins.str
    ts: builtins.float
    def __init__(
        self,
        *,
        rule_ids: collections.abc.Iterable[builtins.str] | None = ...,
        rule_alert_counts: collections.abc.Iterable[builtins.int] | None = ...,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "rule_alert_counts", b"rule_alert_counts", "rule_ids", b"rule_ids", "ts", b"ts"]) -> None: ...

global___SnortIdsRuleCountersDTO = SnortIdsRuleCountersDTO

@typing_extensions.final
class EmulationAttackerActionDTO(google.protobuf.message.Message):
    """DTO with data about an attacker action"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CMDS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCR_FIELD_NUMBER: builtins.int
    IPS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    ACTION_OUTCOME_FIELD_NUMBER: builtins.int
    ALT_CMDS_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    VULNERABILITY_FIELD_NUMBER: builtins.int
    BACKDOOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    name: builtins.str
    @property
    def cmds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    type: builtins.int
    descr: builtins.str
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    index: builtins.int
    action_outcome: builtins.int
    @property
    def alt_cmds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    execution_time: builtins.float
    ts: builtins.float
    vulnerability: builtins.str
    backdoor: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        cmds: collections.abc.Iterable[builtins.str] | None = ...,
        type: builtins.int = ...,
        descr: builtins.str = ...,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        index: builtins.int = ...,
        action_outcome: builtins.int = ...,
        alt_cmds: collections.abc.Iterable[builtins.str] | None = ...,
        execution_time: builtins.float = ...,
        ts: builtins.float = ...,
        vulnerability: builtins.str = ...,
        backdoor: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_outcome", b"action_outcome", "alt_cmds", b"alt_cmds", "backdoor", b"backdoor", "cmds", b"cmds", "descr", b"descr", "execution_time", b"execution_time", "id", b"id", "index", b"index", "ips", b"ips", "name", b"name", "ts", b"ts", "type", b"type", "vulnerability", b"vulnerability"]) -> None: ...

global___EmulationAttackerActionDTO = EmulationAttackerActionDTO

@typing_extensions.final
class EmulationDefenderActionDTO(google.protobuf.message.Message):
    """DTO with data about a defender action"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CMDS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCR_FIELD_NUMBER: builtins.int
    IPS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    ACTION_OUTCOME_FIELD_NUMBER: builtins.int
    ALT_CMDS_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    id: builtins.int
    name: builtins.str
    @property
    def cmds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    type: builtins.int
    descr: builtins.str
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    index: builtins.int
    action_outcome: builtins.int
    @property
    def alt_cmds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    execution_time: builtins.float
    ts: builtins.float
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        cmds: collections.abc.Iterable[builtins.str] | None = ...,
        type: builtins.int = ...,
        descr: builtins.str = ...,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        index: builtins.int = ...,
        action_outcome: builtins.int = ...,
        alt_cmds: collections.abc.Iterable[builtins.str] | None = ...,
        execution_time: builtins.float = ...,
        ts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_outcome", b"action_outcome", "alt_cmds", b"alt_cmds", "cmds", b"cmds", "descr", b"descr", "execution_time", b"execution_time", "id", b"id", "index", b"index", "ips", b"ips", "name", b"name", "ts", b"ts", "type", b"type"]) -> None: ...

global___EmulationDefenderActionDTO = EmulationDefenderActionDTO

@typing_extensions.final
class HostMetricsDataDTO(google.protobuf.message.Message):
    """DTO with host metrics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_LOGGED_IN_USERS_FIELD_NUMBER: builtins.int
    NUM_FAILED_LOGIN_ATTEMPTS_FIELD_NUMBER: builtins.int
    NUM_OPEN_CONNECTIONS_FIELD_NUMBER: builtins.int
    NUM_LOGIN_EVENTS_FIELD_NUMBER: builtins.int
    NUM_PROCESSES_FIELD_NUMBER: builtins.int
    NUM_USERS_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    num_logged_in_users: builtins.int
    num_failed_login_attempts: builtins.int
    num_open_connections: builtins.int
    num_login_events: builtins.int
    num_processes: builtins.int
    num_users: builtins.int
    ip: builtins.str
    ts: builtins.float
    def __init__(
        self,
        *,
        num_logged_in_users: builtins.int = ...,
        num_failed_login_attempts: builtins.int = ...,
        num_open_connections: builtins.int = ...,
        num_login_events: builtins.int = ...,
        num_processes: builtins.int = ...,
        num_users: builtins.int = ...,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "num_failed_login_attempts", b"num_failed_login_attempts", "num_logged_in_users", b"num_logged_in_users", "num_login_events", b"num_login_events", "num_open_connections", b"num_open_connections", "num_processes", b"num_processes", "num_users", b"num_users", "ts", b"ts"]) -> None: ...

global___HostMetricsDataDTO = HostMetricsDataDTO

@typing_extensions.final
class DockerStatsDTO(google.protobuf.message.Message):
    """DTO with docker statistics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIDS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CPU_PERCENT_FIELD_NUMBER: builtins.int
    MEM_CURRENT_FIELD_NUMBER: builtins.int
    MEM_TOTAL_FIELD_NUMBER: builtins.int
    MEM_PERCENT_FIELD_NUMBER: builtins.int
    BLK_READ_FIELD_NUMBER: builtins.int
    BLK_WRITE_FIELD_NUMBER: builtins.int
    NET_RX_FIELD_NUMBER: builtins.int
    NET_TX_FIELD_NUMBER: builtins.int
    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    pids: builtins.float
    timestamp: builtins.str
    cpu_percent: builtins.float
    mem_current: builtins.float
    mem_total: builtins.float
    mem_percent: builtins.float
    blk_read: builtins.float
    blk_write: builtins.float
    net_rx: builtins.float
    net_tx: builtins.float
    container_name: builtins.str
    ip: builtins.str
    ts: builtins.float
    def __init__(
        self,
        *,
        pids: builtins.float = ...,
        timestamp: builtins.str = ...,
        cpu_percent: builtins.float = ...,
        mem_current: builtins.float = ...,
        mem_total: builtins.float = ...,
        mem_percent: builtins.float = ...,
        blk_read: builtins.float = ...,
        blk_write: builtins.float = ...,
        net_rx: builtins.float = ...,
        net_tx: builtins.float = ...,
        container_name: builtins.str = ...,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["blk_read", b"blk_read", "blk_write", b"blk_write", "container_name", b"container_name", "cpu_percent", b"cpu_percent", "ip", b"ip", "mem_current", b"mem_current", "mem_percent", b"mem_percent", "mem_total", b"mem_total", "net_rx", b"net_rx", "net_tx", b"net_tx", "pids", b"pids", "timestamp", b"timestamp", "ts", b"ts"]) -> None: ...

global___DockerStatsDTO = DockerStatsDTO

@typing_extensions.final
class ClientPopulationMetricsDTO(google.protobuf.message.Message):
    """DTO with client population metrics"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    NUM_CLIENTS_FIELD_NUMBER: builtins.int
    RATE_FIELD_NUMBER: builtins.int
    SERVICE_TIME_FIELD_NUMBER: builtins.int
    ip: builtins.str
    ts: builtins.float
    num_clients: builtins.int
    rate: builtins.float
    service_time: builtins.float
    def __init__(
        self,
        *,
        ip: builtins.str = ...,
        ts: builtins.float = ...,
        num_clients: builtins.int = ...,
        rate: builtins.float = ...,
        service_time: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "num_clients", b"num_clients", "rate", b"rate", "service_time", b"service_time", "ts", b"ts"]) -> None: ...

global___ClientPopulationMetricsDTO = ClientPopulationMetricsDTO

@typing_extensions.final
class GetClusterManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the flask logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetClusterManagerLogsMsg = GetClusterManagerLogsMsg

@typing_extensions.final
class GetContainerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetContainerLogsMsg = GetContainerLogsMsg

@typing_extensions.final
class GetClientManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific client manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetClientManagerLogsMsg = GetClientManagerLogsMsg

@typing_extensions.final
class GetKafkaManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific kafka manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetKafkaManagerLogsMsg = GetKafkaManagerLogsMsg

@typing_extensions.final
class GetKafkaLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific kafka server"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetKafkaLogsMsg = GetKafkaLogsMsg

@typing_extensions.final
class GetSnortIdsLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific Snort IDS"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetSnortIdsLogsMsg = GetSnortIdsLogsMsg

@typing_extensions.final
class GetSnortIdsManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific Snort IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetSnortIdsManagerLogsMsg = GetSnortIdsManagerLogsMsg

@typing_extensions.final
class GetOSSECIdsManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific OSSEC IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetOSSECIdsManagerLogsMsg = GetOSSECIdsManagerLogsMsg

@typing_extensions.final
class GetOSSECIdsLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific OSSEC IDS"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetOSSECIdsLogsMsg = GetOSSECIdsLogsMsg

@typing_extensions.final
class GetHostManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific host manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetHostManagerLogsMsg = GetHostManagerLogsMsg

@typing_extensions.final
class GetTrafficManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific traffic manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetTrafficManagerLogsMsg = GetTrafficManagerLogsMsg

@typing_extensions.final
class GetElkManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific ELK manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetElkManagerLogsMsg = GetElkManagerLogsMsg

@typing_extensions.final
class GetElkLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific ELK stack"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetElkLogsMsg = GetElkLogsMsg

@typing_extensions.final
class GetRyuManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific Ryu manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetRyuManagerLogsMsg = GetRyuManagerLogsMsg

@typing_extensions.final
class GetRyuControllerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific Ryu controller"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetRyuControllerLogsMsg = GetRyuControllerLogsMsg

@typing_extensions.final
class StopRyuMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Ryu monitor thread of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopRyuMonitorThreadMsg = StopRyuMonitorThreadMsg

@typing_extensions.final
class StartRyuMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Ryu monitor thread of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartRyuMonitorThreadMsg = StartRyuMonitorThreadMsg

@typing_extensions.final
class StopHostMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Host manager threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopHostMonitorThreadsMsg = StopHostMonitorThreadsMsg

@typing_extensions.final
class StopHostMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Host manager threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopHostMonitorThreadMsg = StopHostMonitorThreadMsg

@typing_extensions.final
class RemoveKibanaTunnelMsg(google.protobuf.message.Message):
    """Message that the client sends to remove a Kibana tunnel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___RemoveKibanaTunnelMsg = RemoveKibanaTunnelMsg

@typing_extensions.final
class CreateKibanaTunnelMsg(google.protobuf.message.Message):
    """Message that the client sends to create a Kibana tunnel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateKibanaTunnelMsg = CreateKibanaTunnelMsg

@typing_extensions.final
class ListKibanaTunnelsMsg(google.protobuf.message.Message):
    """Message that the client sends to request information about Kibana tunnels"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListKibanaTunnelsMsg = ListKibanaTunnelsMsg

@typing_extensions.final
class KibanaTunnelsDTO(google.protobuf.message.Message):
    """Message that the server returns when the client requests information about the Kibana tunnels"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNNELS_FIELD_NUMBER: builtins.int
    @property
    def tunnels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KibanaTunnelDTO]: ...
    def __init__(
        self,
        *,
        tunnels: collections.abc.Iterable[global___KibanaTunnelDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tunnels", b"tunnels"]) -> None: ...

global___KibanaTunnelsDTO = KibanaTunnelsDTO

@typing_extensions.final
class KibanaTunnelDTO(google.protobuf.message.Message):
    """Message that the server returns when the client requests information about the Kibana tunnels"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    port: builtins.int
    ip: builtins.str
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        ip: builtins.str = ...,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ip", b"ip", "ipFirstOctet", b"ipFirstOctet", "port", b"port"]) -> None: ...

global___KibanaTunnelDTO = KibanaTunnelDTO

@typing_extensions.final
class RemoveRyuTunnelMsg(google.protobuf.message.Message):
    """Message that the client sends to remove a Ryu tunnel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___RemoveRyuTunnelMsg = RemoveRyuTunnelMsg

@typing_extensions.final
class CreateRyuTunnelMsg(google.protobuf.message.Message):
    """Message that the client sends to request to create a Ryu tunnel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateRyuTunnelMsg = CreateRyuTunnelMsg

@typing_extensions.final
class ListRyuTunnelsMsg(google.protobuf.message.Message):
    """Message that the client sends to request information about Ryu tunnels"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListRyuTunnelsMsg = ListRyuTunnelsMsg

@typing_extensions.final
class RyuTunnelsDTO(google.protobuf.message.Message):
    """Message that the server returns when the client requests information about the Ryu tunnels"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNNELS_FIELD_NUMBER: builtins.int
    @property
    def tunnels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RyuTunnelDTO]: ...
    def __init__(
        self,
        *,
        tunnels: collections.abc.Iterable[global___RyuTunnelDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tunnels", b"tunnels"]) -> None: ...

global___RyuTunnelsDTO = RyuTunnelsDTO

@typing_extensions.final
class RyuTunnelDTO(google.protobuf.message.Message):
    """Message that the server returns when the client requests information about the Ryu tunnels"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    port: builtins.int
    ip: builtins.str
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        ip: builtins.str = ...,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ip", b"ip", "ipFirstOctet", b"ipFirstOctet", "port", b"port"]) -> None: ...

global___RyuTunnelDTO = RyuTunnelDTO

@typing_extensions.final
class SnortIdsMonitorThreadStatusesDTO(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the statuses of all Snort IDS monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNORTIDSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def snortIDSStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsStatusDTO]: ...
    def __init__(
        self,
        *,
        snortIDSStatuses: collections.abc.Iterable[global___SnortIdsStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["snortIDSStatuses", b"snortIDSStatuses"]) -> None: ...

global___SnortIdsMonitorThreadStatusesDTO = SnortIdsMonitorThreadStatusesDTO

@typing_extensions.final
class GetSnortIdsManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the Snort IDS managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetSnortIdsManagersInfoMsg = GetSnortIdsManagersInfoMsg

@typing_extensions.final
class GetSnortIdsMonitorThreadStatusesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to to get the statuses of all Snort IDS monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetSnortIdsMonitorThreadStatusesMsg = GetSnortIdsMonitorThreadStatusesMsg

@typing_extensions.final
class StopSnortIdsMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop all OSSEC IDSes monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortIdsMonitorThreadsMsg = StopSnortIdsMonitorThreadsMsg

@typing_extensions.final
class StopSnortIdsManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific Snort IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortIdsManagerMsg = StopSnortIdsManagerMsg

@typing_extensions.final
class StartSnortIdsManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific Snort manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortIdsManagerMsg = StartSnortIdsManagerMsg

@typing_extensions.final
class StopSnortIdsManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop Snort managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortIdsManagersMsg = StopSnortIdsManagersMsg

@typing_extensions.final
class StartSnortIdsManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start Snort IDS managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortIdsManagersMsg = StartSnortIdsManagersMsg

@typing_extensions.final
class StartSnortMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific Snort IDS"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortMsg = StartSnortMsg

@typing_extensions.final
class StartSnortIdsMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific Snort IDS monitor thread"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortIdsMonitorThreadMsg = StartSnortIdsMonitorThreadMsg

@typing_extensions.final
class StartSnortIdsMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start all Snort IDS monitor thread of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortIdsMonitorThreadsMsg = StartSnortIdsMonitorThreadsMsg

@typing_extensions.final
class StopSnortMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific Snort IDS"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortMsg = StopSnortMsg

@typing_extensions.final
class StopSnortIdsMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific Snort IDS monitor thread"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortIdsMonitorThreadMsg = StopSnortIdsMonitorThreadMsg

@typing_extensions.final
class StopSnortIdsesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Snort IDSes of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortIdsesMsg = StopSnortIdsesMsg

@typing_extensions.final
class StopSnortIdsesMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Snort IDSes Monitor threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopSnortIdsesMonitorThreadsMsg = StopSnortIdsesMonitorThreadsMsg

@typing_extensions.final
class GetRyuManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the Ryu managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetRyuManagersInfoMsg = GetRyuManagersInfoMsg

@typing_extensions.final
class StopRyuMonitorServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Ryu monitor of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopRyuMonitorServiceMsg = StopRyuMonitorServiceMsg

@typing_extensions.final
class StartRyuMonitorServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Ryu monitor of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartRyuMonitorServiceMsg = StartRyuMonitorServiceMsg

@typing_extensions.final
class StopRyuServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop Ryu of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopRyuServiceMsg = StopRyuServiceMsg

@typing_extensions.final
class StartRyuServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start Ryu of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartRyuServiceMsg = StartRyuServiceMsg

@typing_extensions.final
class GetRyuServiceStatusMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the status of teh Ryu manager of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetRyuServiceStatusMsg = GetRyuServiceStatusMsg

@typing_extensions.final
class StopRyuManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Ryu manager of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopRyuManagerMsg = StopRyuManagerMsg

@typing_extensions.final
class StartRyuManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Ryu manager of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartRyuManagerMsg = StartRyuManagerMsg

@typing_extensions.final
class GetOSSECIDSManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the OSSEC IDS managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetOSSECIDSManagersInfoMsg = GetOSSECIDSManagersInfoMsg

@typing_extensions.final
class OSSECIdsMonitorThreadStatusesDTO(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the statuses of all OSSEC IDS monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OSSECIDSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ossecIDSStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OSSECIdsStatusDTO]: ...
    def __init__(
        self,
        *,
        ossecIDSStatuses: collections.abc.Iterable[global___OSSECIdsStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ossecIDSStatuses", b"ossecIDSStatuses"]) -> None: ...

global___OSSECIdsMonitorThreadStatusesDTO = OSSECIdsMonitorThreadStatusesDTO

@typing_extensions.final
class GetOSSECIDSMonitorThreadStatusesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop all OSSEC IDSes monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetOSSECIDSMonitorThreadStatusesMsg = GetOSSECIDSMonitorThreadStatusesMsg

@typing_extensions.final
class StopOSSECIDSMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop all OSSEC IDSes monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopOSSECIDSMonitorThreadsMsg = StopOSSECIDSMonitorThreadsMsg

@typing_extensions.final
class StopOSSECIDSMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific OSSEC IDSes monitor thread"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopOSSECIDSMonitorThreadMsg = StopOSSECIDSMonitorThreadMsg

@typing_extensions.final
class StartOSSECIDSMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific OSSEC IDSes monitor thread"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIDSMonitorThreadMsg = StartOSSECIDSMonitorThreadMsg

@typing_extensions.final
class StopOSSECIDSManager(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific OSSEC IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopOSSECIDSManager = StopOSSECIDSManager

@typing_extensions.final
class StartOSSECIDSManager(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific OSSEC IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIDSManager = StartOSSECIDSManager

@typing_extensions.final
class StopOSSECIDSManagers(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop OSSEC IDS managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopOSSECIDSManagers = StopOSSECIDSManagers

@typing_extensions.final
class StartOSSECIDSManagers(google.protobuf.message.Message):
    """Message that the client sends when requesting to start OSSEC IDS managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIDSManagers = StartOSSECIDSManagers

@typing_extensions.final
class StartOSSECIDSMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific OSSEC IDS"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIDSMsg = StartOSSECIDSMsg

@typing_extensions.final
class StopOSSECIDSMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific OSSEC IDS"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopOSSECIDSMsg = StopOSSECIDSMsg

@typing_extensions.final
class StartOSSECIDSesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the OSSEC IDSes"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIDSesMsg = StartOSSECIDSesMsg

@typing_extensions.final
class StopOSSECIDSesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the OSSEC IDSes"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopOSSECIDSesMsg = StopOSSECIDSesMsg

@typing_extensions.final
class GetKafkaManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the kafka managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetKafkaManagersInfoMsg = GetKafkaManagersInfoMsg

@typing_extensions.final
class StartKafkaServerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Kafka server of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartKafkaServerMsg = StartKafkaServerMsg

@typing_extensions.final
class StopKafkaServerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Kafka server of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopKafkaServerMsg = StopKafkaServerMsg

@typing_extensions.final
class GetKafkaManagerStatusMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the status of Kafka in a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetKafkaManagerStatusMsg = GetKafkaManagerStatusMsg

@typing_extensions.final
class CreateKafkaTopicsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create Kafka topics of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateKafkaTopicsMsg = CreateKafkaTopicsMsg

@typing_extensions.final
class StopKafkaManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Kafka manager of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopKafkaManagerMsg = StopKafkaManagerMsg

@typing_extensions.final
class StartKafkaManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Kafka manager of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartKafkaManagerMsg = StartKafkaManagerMsg

@typing_extensions.final
class GetHostManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the host managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetHostManagersInfoMsg = GetHostManagersInfoMsg

@typing_extensions.final
class GetHostMonitorThreadsStatusesMsg(google.protobuf.message.Message):
    """Message that the client sends to request the statuses of host monitor threads"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetHostMonitorThreadsStatusesMsg = GetHostMonitorThreadsStatusesMsg

@typing_extensions.final
class ApplyFileBeatConfigMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the filebeat configuration of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyFileBeatConfigMsg = ApplyFileBeatConfigMsg

@typing_extensions.final
class ApplyPacketBeatConfigMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the packetbeat configuration of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyPacketBeatConfigMsg = ApplyPacketBeatConfigMsg

@typing_extensions.final
class ApplyMetricBeatConfigMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the metricbeat configuration of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyMetricBeatConfigMsg = ApplyMetricBeatConfigMsg

@typing_extensions.final
class ApplyHeartBeatConfigMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the heartbeat configuration of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyHeartBeatConfigMsg = ApplyHeartBeatConfigMsg

@typing_extensions.final
class StopFileBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop filebeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopFileBeatMsg = StopFileBeatMsg

@typing_extensions.final
class StopPacketBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop packetbeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopPacketBeatMsg = StopPacketBeatMsg

@typing_extensions.final
class StopMetricBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop metricbeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopMetricBeatMsg = StopMetricBeatMsg

@typing_extensions.final
class StopHeartBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start heartbeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopHeartBeatMsg = StopHeartBeatMsg

@typing_extensions.final
class StartFileBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start filebeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartFileBeatMsg = StartFileBeatMsg

@typing_extensions.final
class StartPacketBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start packetbeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartPacketBeatMsg = StartPacketBeatMsg

@typing_extensions.final
class StartMetricBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start metricbeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartMetricBeatMsg = StartMetricBeatMsg

@typing_extensions.final
class StartHeartBeatMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start heartbeat of a specific container in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartHeartBeatMsg = StartHeartBeatMsg

@typing_extensions.final
class StartHostMonitorThreadMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Host manager threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartHostMonitorThreadMsg = StartHostMonitorThreadMsg

@typing_extensions.final
class StopHeartbeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the heartbeats of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopHeartbeatsMsg = StopHeartbeatsMsg

@typing_extensions.final
class StopPacketbeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the packetbeats of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopPacketbeatsMsg = StopPacketbeatsMsg

@typing_extensions.final
class StopFilebeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the filebeats of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopFilebeatsMsg = StopFilebeatsMsg

@typing_extensions.final
class StopMetricbeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the metricbeats of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopMetricbeatsMsg = StopMetricbeatsMsg

@typing_extensions.final
class StartHostMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Host manager threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartHostMonitorThreadsMsg = StartHostMonitorThreadsMsg

@typing_extensions.final
class StopHostManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Host manager of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopHostManagerMsg = StopHostManagerMsg

@typing_extensions.final
class StartHostManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Host managers of a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartHostManagerMsg = StartHostManagerMsg

@typing_extensions.final
class StopHostManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the Host managers of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopHostManagersMsg = StopHostManagersMsg

@typing_extensions.final
class ExecutionInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the elk managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    SNORTIDSMANAGERSINFO_FIELD_NUMBER: builtins.int
    OSSECIDSMANAGERSINFO_FIELD_NUMBER: builtins.int
    KAFKAMANAGERSINFO_FIELD_NUMBER: builtins.int
    HOSTMANAGERSINFO_FIELD_NUMBER: builtins.int
    CLIENTMANAGERSINFO_FIELD_NUMBER: builtins.int
    DOCKERSTATSMANAGERSINFO_FIELD_NUMBER: builtins.int
    RUNNINGCONTAINERS_FIELD_NUMBER: builtins.int
    STOPPEDCONTAINERS_FIELD_NUMBER: builtins.int
    TRAFFICMANAGERSINFODTO_FIELD_NUMBER: builtins.int
    ACTIVENETWORKS_FIELD_NUMBER: builtins.int
    ELKMANAGERSINFODTO_FIELD_NUMBER: builtins.int
    RYUMANAGERSINFODTO_FIELD_NUMBER: builtins.int
    FIVEGCOREMANAGERSINFODTO_FIELD_NUMBER: builtins.int
    FIVEGCUMANAGERSINFODTO_FIELD_NUMBER: builtins.int
    FIVEGDUMANAGERSINFODTO_FIELD_NUMBER: builtins.int
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def snortIdsManagersInfo(self) -> global___SnortIdsManagersInfoDTO: ...
    @property
    def ossecIdsManagersInfo(self) -> global___OSSECIdsManagersInfoDTO: ...
    @property
    def kafkaManagersInfo(self) -> global___KafkaManagersInfoDTO: ...
    @property
    def hostManagersInfo(self) -> global___HostManagersInfoDTO: ...
    @property
    def clientManagersInfo(self) -> global___ClientManagersInfoDTO: ...
    @property
    def dockerStatsManagersInfo(self) -> global___DockerStatsManagersInfoDTO: ...
    @property
    def runningContainers(self) -> global___RunningContainersDTO: ...
    @property
    def stoppedContainers(self) -> global___StoppedContainersDTO: ...
    @property
    def trafficManagersInfoDTO(self) -> global___TrafficManagersInfoDTO: ...
    @property
    def activeNetworks(self) -> global___DockerNetworksDTO: ...
    @property
    def elkManagersInfoDTO(self) -> global___ElkManagersInfoDTO: ...
    @property
    def ryuManagersInfoDTO(self) -> global___RyuManagersInfoDTO: ...
    @property
    def fiveGCoreManagersInfoDTO(self) -> global___FiveGCoreManagersInfoDTO: ...
    @property
    def fiveGCUManagersInfoDTO(self) -> global___FiveGCUManagersInfoDTO: ...
    @property
    def fiveGDUManagersInfoDTO(self) -> global___FiveGDUManagersInfoDTO: ...
    def __init__(
        self,
        *,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        snortIdsManagersInfo: global___SnortIdsManagersInfoDTO | None = ...,
        ossecIdsManagersInfo: global___OSSECIdsManagersInfoDTO | None = ...,
        kafkaManagersInfo: global___KafkaManagersInfoDTO | None = ...,
        hostManagersInfo: global___HostManagersInfoDTO | None = ...,
        clientManagersInfo: global___ClientManagersInfoDTO | None = ...,
        dockerStatsManagersInfo: global___DockerStatsManagersInfoDTO | None = ...,
        runningContainers: global___RunningContainersDTO | None = ...,
        stoppedContainers: global___StoppedContainersDTO | None = ...,
        trafficManagersInfoDTO: global___TrafficManagersInfoDTO | None = ...,
        activeNetworks: global___DockerNetworksDTO | None = ...,
        elkManagersInfoDTO: global___ElkManagersInfoDTO | None = ...,
        ryuManagersInfoDTO: global___RyuManagersInfoDTO | None = ...,
        fiveGCoreManagersInfoDTO: global___FiveGCoreManagersInfoDTO | None = ...,
        fiveGCUManagersInfoDTO: global___FiveGCUManagersInfoDTO | None = ...,
        fiveGDUManagersInfoDTO: global___FiveGDUManagersInfoDTO | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activeNetworks", b"activeNetworks", "clientManagersInfo", b"clientManagersInfo", "dockerStatsManagersInfo", b"dockerStatsManagersInfo", "elkManagersInfoDTO", b"elkManagersInfoDTO", "fiveGCUManagersInfoDTO", b"fiveGCUManagersInfoDTO", "fiveGCoreManagersInfoDTO", b"fiveGCoreManagersInfoDTO", "fiveGDUManagersInfoDTO", b"fiveGDUManagersInfoDTO", "hostManagersInfo", b"hostManagersInfo", "kafkaManagersInfo", b"kafkaManagersInfo", "ossecIdsManagersInfo", b"ossecIdsManagersInfo", "runningContainers", b"runningContainers", "ryuManagersInfoDTO", b"ryuManagersInfoDTO", "snortIdsManagersInfo", b"snortIdsManagersInfo", "stoppedContainers", b"stoppedContainers", "trafficManagersInfoDTO", b"trafficManagersInfoDTO"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activeNetworks", b"activeNetworks", "clientManagersInfo", b"clientManagersInfo", "dockerStatsManagersInfo", b"dockerStatsManagersInfo", "elkManagersInfoDTO", b"elkManagersInfoDTO", "emulationName", b"emulationName", "executionId", b"executionId", "fiveGCUManagersInfoDTO", b"fiveGCUManagersInfoDTO", "fiveGCoreManagersInfoDTO", b"fiveGCoreManagersInfoDTO", "fiveGDUManagersInfoDTO", b"fiveGDUManagersInfoDTO", "hostManagersInfo", b"hostManagersInfo", "kafkaManagersInfo", b"kafkaManagersInfo", "ossecIdsManagersInfo", b"ossecIdsManagersInfo", "runningContainers", b"runningContainers", "ryuManagersInfoDTO", b"ryuManagersInfoDTO", "snortIdsManagersInfo", b"snortIdsManagersInfo", "stoppedContainers", b"stoppedContainers", "trafficManagersInfoDTO", b"trafficManagersInfoDTO"]) -> None: ...

global___ExecutionInfoDTO = ExecutionInfoDTO

@typing_extensions.final
class RyuManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the Ryu managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    RYUMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    RYUMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    LOCALCONTROLLERWEBPORT_FIELD_NUMBER: builtins.int
    PHYSICALSERVERIP_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def ryuManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def ryuManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RyuManagerStatusDTO]: ...
    localControllerWebPort: builtins.int
    physicalServerIp: builtins.str
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        ryuManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        ryuManagersStatuses: collections.abc.Iterable[global___RyuManagerStatusDTO] | None = ...,
        localControllerWebPort: builtins.int = ...,
        physicalServerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "localControllerWebPort", b"localControllerWebPort", "physicalServerIp", b"physicalServerIp", "ports", b"ports", "ryuManagersRunning", b"ryuManagersRunning", "ryuManagersStatuses", b"ryuManagersStatuses"]) -> None: ...

global___RyuManagersInfoDTO = RyuManagersInfoDTO

@typing_extensions.final
class RyuManagerStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the status of the Ryu manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RYU_RUNNING_FIELD_NUMBER: builtins.int
    MONITOR_RUNNING_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    WEB_PORT_FIELD_NUMBER: builtins.int
    CONTROLLER_FIELD_NUMBER: builtins.int
    KAFKA_IP_FIELD_NUMBER: builtins.int
    KAFKA_PORT_FIELD_NUMBER: builtins.int
    TIME_STEP_LEN_FIELD_NUMBER: builtins.int
    ryu_running: builtins.bool
    monitor_running: builtins.bool
    port: builtins.int
    web_port: builtins.int
    controller: builtins.str
    kafka_ip: builtins.str
    kafka_port: builtins.int
    time_step_len: builtins.int
    def __init__(
        self,
        *,
        ryu_running: builtins.bool = ...,
        monitor_running: builtins.bool = ...,
        port: builtins.int = ...,
        web_port: builtins.int = ...,
        controller: builtins.str = ...,
        kafka_ip: builtins.str = ...,
        kafka_port: builtins.int = ...,
        time_step_len: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["controller", b"controller", "kafka_ip", b"kafka_ip", "kafka_port", b"kafka_port", "monitor_running", b"monitor_running", "port", b"port", "ryu_running", b"ryu_running", "time_step_len", b"time_step_len", "web_port", b"web_port"]) -> None: ...

global___RyuManagerStatusDTO = RyuManagerStatusDTO

@typing_extensions.final
class HostManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the Host managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    HOSTMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    HOSTMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def hostManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def hostManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostManagerStatusDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        hostManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        hostManagersStatuses: collections.abc.Iterable[global___HostManagerStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "hostManagersRunning", b"hostManagersRunning", "hostManagersStatuses", b"hostManagersStatuses", "ips", b"ips", "ports", b"ports"]) -> None: ...

global___HostManagersInfoDTO = HostManagersInfoDTO

@typing_extensions.final
class HostManagerStatusesDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the statuses of the Host managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTMANAGERSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def hostManagerStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostManagerStatusDTO]: ...
    def __init__(
        self,
        *,
        hostManagerStatuses: collections.abc.Iterable[global___HostManagerStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostManagerStatuses", b"hostManagerStatuses"]) -> None: ...

global___HostManagerStatusesDTO = HostManagerStatusesDTO

@typing_extensions.final
class HostManagerStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the status of the Host manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITOR_RUNNING_FIELD_NUMBER: builtins.int
    FILEBEAT_RUNNING_FIELD_NUMBER: builtins.int
    PACKETBEAT_RUNNING_FIELD_NUMBER: builtins.int
    METRICBEAT_RUNNING_FIELD_NUMBER: builtins.int
    HEARTBEAT_RUNNING_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    monitor_running: builtins.bool
    filebeat_running: builtins.bool
    packetbeat_running: builtins.bool
    metricbeat_running: builtins.bool
    heartbeat_running: builtins.bool
    ip: builtins.str
    def __init__(
        self,
        *,
        monitor_running: builtins.bool = ...,
        filebeat_running: builtins.bool = ...,
        packetbeat_running: builtins.bool = ...,
        metricbeat_running: builtins.bool = ...,
        heartbeat_running: builtins.bool = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filebeat_running", b"filebeat_running", "heartbeat_running", b"heartbeat_running", "ip", b"ip", "metricbeat_running", b"metricbeat_running", "monitor_running", b"monitor_running", "packetbeat_running", b"packetbeat_running"]) -> None: ...

global___HostManagerStatusDTO = HostManagerStatusDTO

@typing_extensions.final
class KafkaManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the Kafka managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    KAFKAMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    KAFKAMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def kafkaManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def kafkaManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KafkaStatusDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        kafkaManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        kafkaManagersStatuses: collections.abc.Iterable[global___KafkaStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "kafkaManagersRunning", b"kafkaManagersRunning", "kafkaManagersStatuses", b"kafkaManagersStatuses", "ports", b"ports"]) -> None: ...

global___KafkaManagersInfoDTO = KafkaManagersInfoDTO

@typing_extensions.final
class KafkaStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the status of the Kafka manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    running: builtins.bool
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        running: builtins.bool = ...,
        topics: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["running", b"running", "topics", b"topics"]) -> None: ...

global___KafkaStatusDTO = KafkaStatusDTO

@typing_extensions.final
class OSSECIdsManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the OSSEC IDS managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    OSSECIDSMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    OSSECIDSMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def ossecIdsManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def ossecIdsManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OSSECIdsStatusDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        ossecIdsManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        ossecIdsManagersStatuses: collections.abc.Iterable[global___OSSECIdsStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "ossecIdsManagersRunning", b"ossecIdsManagersRunning", "ossecIdsManagersStatuses", b"ossecIdsManagersStatuses", "ports", b"ports"]) -> None: ...

global___OSSECIdsManagersInfoDTO = OSSECIdsManagersInfoDTO

@typing_extensions.final
class OSSECIdsStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the status of the OSSEC IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITOR_RUNNING_FIELD_NUMBER: builtins.int
    OSSEC_IDS_RUNNING_FIELD_NUMBER: builtins.int
    monitor_running: builtins.bool
    ossec_ids_running: builtins.bool
    def __init__(
        self,
        *,
        monitor_running: builtins.bool = ...,
        ossec_ids_running: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitor_running", b"monitor_running", "ossec_ids_running", b"ossec_ids_running"]) -> None: ...

global___OSSECIdsStatusDTO = OSSECIdsStatusDTO

@typing_extensions.final
class SnortIdsManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the Snort IDS managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    SNORTIDSMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    SNORTIDSMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def snortIdsManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def snortIdsManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SnortIdsStatusDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        snortIdsManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        snortIdsManagersStatuses: collections.abc.Iterable[global___SnortIdsStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "ports", b"ports", "snortIdsManagersRunning", b"snortIdsManagersRunning", "snortIdsManagersStatuses", b"snortIdsManagersStatuses"]) -> None: ...

global___SnortIdsManagersInfoDTO = SnortIdsManagersInfoDTO

@typing_extensions.final
class SnortIdsStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the status of the Snort IDS manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITOR_RUNNING_FIELD_NUMBER: builtins.int
    SNORT_IDS_RUNNING_FIELD_NUMBER: builtins.int
    monitor_running: builtins.bool
    snort_ids_running: builtins.bool
    def __init__(
        self,
        *,
        monitor_running: builtins.bool = ...,
        snort_ids_running: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitor_running", b"monitor_running", "snort_ids_running", b"snort_ids_running"]) -> None: ...

global___SnortIdsStatusDTO = SnortIdsStatusDTO

@typing_extensions.final
class GetExecutionInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get information about a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetExecutionInfoMsg = GetExecutionInfoMsg

@typing_extensions.final
class StopContainersOfExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the containers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopContainersOfExecutionMsg = StopContainersOfExecutionMsg

@typing_extensions.final
class RunContainerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the containers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    NUM_CPUS_FIELD_NUMBER: builtins.int
    CREATE_NETWORK_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    image: builtins.str
    name: builtins.str
    memory: builtins.int
    num_cpus: builtins.int
    create_network: builtins.bool
    version: builtins.str
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        name: builtins.str = ...,
        memory: builtins.int = ...,
        num_cpus: builtins.int = ...,
        create_network: builtins.bool = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_network", b"create_network", "image", b"image", "memory", b"memory", "name", b"name", "num_cpus", b"num_cpus", "version", b"version"]) -> None: ...

global___RunContainerMsg = RunContainerMsg

@typing_extensions.final
class StartContainersOfExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the containers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartContainersOfExecutionMsg = StartContainersOfExecutionMsg

@typing_extensions.final
class GetElkManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the elk managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetElkManagersInfoMsg = GetElkManagersInfoMsg

@typing_extensions.final
class ElkManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the elk managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    ELKMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    ELKMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    LOCALKIBANAPORT_FIELD_NUMBER: builtins.int
    PHYSICALSERVERIP_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def elkManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def elkManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ElkStatusDTO]: ...
    localKibanaPort: builtins.int
    physicalServerIp: builtins.str
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        elkManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        elkManagersStatuses: collections.abc.Iterable[global___ElkStatusDTO] | None = ...,
        localKibanaPort: builtins.int = ...,
        physicalServerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["elkManagersRunning", b"elkManagersRunning", "elkManagersStatuses", b"elkManagersStatuses", "emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "localKibanaPort", b"localKibanaPort", "physicalServerIp", b"physicalServerIp", "ports", b"ports"]) -> None: ...

global___ElkManagersInfoDTO = ElkManagersInfoDTO

@typing_extensions.final
class StopLogstashServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop logstash for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopLogstashServiceMsg = StopLogstashServiceMsg

@typing_extensions.final
class StartLogstashServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start logstash for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartLogstashServiceMsg = StartLogstashServiceMsg

@typing_extensions.final
class StopKibanaServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop Kibana for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopKibanaServiceMsg = StopKibanaServiceMsg

@typing_extensions.final
class StartKibanaServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start Kibana for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartKibanaServiceMsg = StartKibanaServiceMsg

@typing_extensions.final
class StopElasticServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop Elastic for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopElasticServiceMsg = StopElasticServiceMsg

@typing_extensions.final
class StartElasticServiceMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start Elastic for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartElasticServiceMsg = StartElasticServiceMsg

@typing_extensions.final
class StopElkStackMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the ELK stack of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopElkStackMsg = StopElkStackMsg

@typing_extensions.final
class ElkStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when requested about status of the ELk stack"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELASTICRUNNING_FIELD_NUMBER: builtins.int
    KIBANARUNNING_FIELD_NUMBER: builtins.int
    LOGSTASHRUNNING_FIELD_NUMBER: builtins.int
    elasticRunning: builtins.bool
    kibanaRunning: builtins.bool
    logstashRunning: builtins.bool
    def __init__(
        self,
        *,
        elasticRunning: builtins.bool = ...,
        kibanaRunning: builtins.bool = ...,
        logstashRunning: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["elasticRunning", b"elasticRunning", "kibanaRunning", b"kibanaRunning", "logstashRunning", b"logstashRunning"]) -> None: ...

global___ElkStatusDTO = ElkStatusDTO

@typing_extensions.final
class GetElkStackStatusMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the status of the ELK stack and the manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetElkStackStatusMsg = GetElkStackStatusMsg

@typing_extensions.final
class StopElkManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the elk manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopElkManagerMsg = StopElkManagerMsg

@typing_extensions.final
class StartElkManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the elk manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartElkManagerMsg = StartElkManagerMsg

@typing_extensions.final
class GetDockerStatsManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the docker stats managers info for a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetDockerStatsManagersInfoMsg = GetDockerStatsManagersInfoMsg

@typing_extensions.final
class DockerStatsManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the docker stats managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    DOCKERSTATSMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    DOCKERSTATSMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def dockerStatsManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def dockerStatsManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerStatsMonitorStatusDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        dockerStatsManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        dockerStatsManagersStatuses: collections.abc.Iterable[global___DockerStatsMonitorStatusDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dockerStatsManagersRunning", b"dockerStatsManagersRunning", "dockerStatsManagersStatuses", b"dockerStatsManagersStatuses", "emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "ports", b"ports"]) -> None: ...

global___DockerStatsManagersInfoDTO = DockerStatsManagersInfoDTO

@typing_extensions.final
class RemoveAllDockerNetworksMsg(google.protobuf.message.Message):
    """Message that the client sends to remove all CSLE docker networks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveAllDockerNetworksMsg = RemoveAllDockerNetworksMsg

@typing_extensions.final
class RemoveDockerNetworksMsg(google.protobuf.message.Message):
    """Message that the client sends to remove a list of docker network"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORKS_FIELD_NUMBER: builtins.int
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        networks: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["networks", b"networks"]) -> None: ...

global___RemoveDockerNetworksMsg = RemoveDockerNetworksMsg

@typing_extensions.final
class DockerStatsMonitorStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when requested by the client, contains info about the docker stats monitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_MONITORS_FIELD_NUMBER: builtins.int
    EMULATIONS_FIELD_NUMBER: builtins.int
    EMULATION_EXECUTIONS_FIELD_NUMBER: builtins.int
    num_monitors: builtins.int
    @property
    def emulations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def emulation_executions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        num_monitors: builtins.int = ...,
        emulations: collections.abc.Iterable[builtins.str] | None = ...,
        emulation_executions: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation_executions", b"emulation_executions", "emulations", b"emulations", "num_monitors", b"num_monitors"]) -> None: ...

global___DockerStatsMonitorStatusDTO = DockerStatsMonitorStatusDTO

@typing_extensions.final
class GetDockerStatsManagerStatusMsg(google.protobuf.message.Message):
    """Message that the client sends to get the status of the docker stats manager of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    port: builtins.int
    def __init__(
        self,
        *,
        port: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port"]) -> None: ...

global___GetDockerStatsManagerStatusMsg = GetDockerStatsManagerStatusMsg

@typing_extensions.final
class StopDockerStatsManagerThreadMsg(google.protobuf.message.Message):
    """Message that the client sends to stop a dockerStatsManager thread for an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopDockerStatsManagerThreadMsg = StopDockerStatsManagerThreadMsg

@typing_extensions.final
class CreateEmulationNetworksMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create emulation networks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateEmulationNetworksMsg = CreateEmulationNetworksMsg

@typing_extensions.final
class ListAllStoppedContainersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to list all stopped containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAllStoppedContainersMsg = ListAllStoppedContainersMsg

@typing_extensions.final
class StoppedContainersDTO(google.protobuf.message.Message):
    """DTO with data related to all stopped containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STOPPEDCONTAINERS_FIELD_NUMBER: builtins.int
    @property
    def stoppedContainers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerContainerDTO]: ...
    def __init__(
        self,
        *,
        stoppedContainers: collections.abc.Iterable[global___DockerContainerDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stoppedContainers", b"stoppedContainers"]) -> None: ...

global___StoppedContainersDTO = StoppedContainersDTO

@typing_extensions.final
class ListAllRunningEmulationsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to list all running emulations"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAllRunningEmulationsMsg = ListAllRunningEmulationsMsg

@typing_extensions.final
class RunningEmulationsDTO(google.protobuf.message.Message):
    """DTO with data related to all running emulations"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNINGEMULATIONS_FIELD_NUMBER: builtins.int
    @property
    def runningEmulations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        runningEmulations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runningEmulations", b"runningEmulations"]) -> None: ...

global___RunningEmulationsDTO = RunningEmulationsDTO

@typing_extensions.final
class ListAllRunningContainersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to list all running containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAllRunningContainersMsg = ListAllRunningContainersMsg

@typing_extensions.final
class RunningContainersDTO(google.protobuf.message.Message):
    """DTO with data related to all running containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNINGCONTAINERS_FIELD_NUMBER: builtins.int
    @property
    def runningContainers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerContainerDTO]: ...
    def __init__(
        self,
        *,
        runningContainers: collections.abc.Iterable[global___DockerContainerDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runningContainers", b"runningContainers"]) -> None: ...

global___RunningContainersDTO = RunningContainersDTO

@typing_extensions.final
class DockerContainerDTO(google.protobuf.message.Message):
    """DTO with data related to a running container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    name: builtins.str
    image: builtins.str
    ip: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        image: builtins.str = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "ip", b"ip", "name", b"name"]) -> None: ...

global___DockerContainerDTO = DockerContainerDTO

@typing_extensions.final
class StartContainerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___StartContainerMsg = StartContainerMsg

@typing_extensions.final
class StartAllStoppedContainersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start all stopped containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartAllStoppedContainersMsg = StartAllStoppedContainersMsg

@typing_extensions.final
class ListAllDockerNetworksMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to list all Docker networks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAllDockerNetworksMsg = ListAllDockerNetworksMsg

@typing_extensions.final
class DockerNetworksDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the Docker networks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORKS_FIELD_NUMBER: builtins.int
    NETWORK_IDS_FIELD_NUMBER: builtins.int
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def network_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        networks: collections.abc.Iterable[builtins.str] | None = ...,
        network_ids: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_ids", b"network_ids", "networks", b"networks"]) -> None: ...

global___DockerNetworksDTO = DockerNetworksDTO

@typing_extensions.final
class ContainerImagesDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the container images"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerImageDTO]: ...
    def __init__(
        self,
        *,
        images: collections.abc.Iterable[global___ContainerImageDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["images", b"images"]) -> None: ...

global___ContainerImagesDTO = ContainerImagesDTO

@typing_extensions.final
class ContainerImageDTO(google.protobuf.message.Message):
    """DTO for a specific container image"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOTAGS_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    repoTags: builtins.str
    created: builtins.str
    os: builtins.str
    architecture: builtins.str
    size: builtins.int
    def __init__(
        self,
        *,
        repoTags: builtins.str = ...,
        created: builtins.str = ...,
        os: builtins.str = ...,
        architecture: builtins.str = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "created", b"created", "os", b"os", "repoTags", b"repoTags", "size", b"size"]) -> None: ...

global___ContainerImageDTO = ContainerImageDTO

@typing_extensions.final
class ListAllContainerImagesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to list all container images"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAllContainerImagesMsg = ListAllContainerImagesMsg

@typing_extensions.final
class RemoveContainerImageMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to remove a specific container image"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RemoveContainerImageMsg = RemoveContainerImageMsg

@typing_extensions.final
class RemoveAllContainerImagesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to remove all container images"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveAllContainerImagesMsg = RemoveAllContainerImagesMsg

@typing_extensions.final
class RemoveAllStoppedContainersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to remove all stopped containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveAllStoppedContainersMsg = RemoveAllStoppedContainersMsg

@typing_extensions.final
class RemoveContainerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to remove a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RemoveContainerMsg = RemoveContainerMsg

@typing_extensions.final
class StopContainerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific container"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___StopContainerMsg = StopContainerMsg

@typing_extensions.final
class StopAllRunningContainersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop all running CSLE containers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopAllRunningContainersMsg = StopAllRunningContainersMsg

@typing_extensions.final
class GetTrafficManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the traffic managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetTrafficManagersInfoMsg = GetTrafficManagersInfoMsg

@typing_extensions.final
class TrafficManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the traffic managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    TRAFFICMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    TRAFFICMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def trafficManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def trafficManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TrafficManagerInfoDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        trafficManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        trafficManagersStatuses: collections.abc.Iterable[global___TrafficManagerInfoDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "ports", b"ports", "trafficManagersRunning", b"trafficManagersRunning", "trafficManagersStatuses", b"trafficManagersStatuses"]) -> None: ...

global___TrafficManagersInfoDTO = TrafficManagersInfoDTO

@typing_extensions.final
class TrafficManagerInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the info of a specific traffic manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    running: builtins.bool
    script: builtins.str
    def __init__(
        self,
        *,
        running: builtins.bool = ...,
        script: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["running", b"running", "script", b"script"]) -> None: ...

global___TrafficManagerInfoDTO = TrafficManagerInfoDTO

@typing_extensions.final
class ClientManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the client managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    CLIENTMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    CLIENTMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def clientManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def clientManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetNumClientsDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        clientManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        clientManagersStatuses: collections.abc.Iterable[global___GetNumClientsDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["clientManagersRunning", b"clientManagersRunning", "clientManagersStatuses", b"clientManagersStatuses", "emulationName", b"emulationName", "executionId", b"executionId", "ips", b"ips", "ports", b"ports"]) -> None: ...

global___ClientManagersInfoDTO = ClientManagersInfoDTO

@typing_extensions.final
class GetClientManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the client managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetClientManagersInfoMsg = GetClientManagersInfoMsg

@typing_extensions.final
class StartTrafficGeneratorMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific traffic generator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartTrafficGeneratorMsg = StartTrafficGeneratorMsg

@typing_extensions.final
class StopTrafficGeneratorMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific traffic generator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopTrafficGeneratorMsg = StopTrafficGeneratorMsg

@typing_extensions.final
class StopTrafficGeneratorsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop all traffic generators of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopTrafficGeneratorsMsg = StopTrafficGeneratorsMsg

@typing_extensions.final
class GetNumClientsDTO(google.protobuf.message.Message):
    """Message that the server returns when the client requested the number of clients of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_CLIENTS_FIELD_NUMBER: builtins.int
    CLIENT_PROCESS_ACTIVE_FIELD_NUMBER: builtins.int
    PRODUCER_ACTIVE_FIELD_NUMBER: builtins.int
    CLIENTS_TIME_STEP_LEN_SECONDS_FIELD_NUMBER: builtins.int
    PRODUCER_TIME_STEP_LEN_SECONDS_FIELD_NUMBER: builtins.int
    num_clients: builtins.int
    client_process_active: builtins.bool
    producer_active: builtins.bool
    clients_time_step_len_seconds: builtins.int
    producer_time_step_len_seconds: builtins.int
    def __init__(
        self,
        *,
        num_clients: builtins.int = ...,
        client_process_active: builtins.bool = ...,
        producer_active: builtins.bool = ...,
        clients_time_step_len_seconds: builtins.int = ...,
        producer_time_step_len_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_process_active", b"client_process_active", "clients_time_step_len_seconds", b"clients_time_step_len_seconds", "num_clients", b"num_clients", "producer_active", b"producer_active", "producer_time_step_len_seconds", b"producer_time_step_len_seconds"]) -> None: ...

global___GetNumClientsDTO = GetNumClientsDTO

@typing_extensions.final
class GetNumActiveClientsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the number of active clients of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___GetNumActiveClientsMsg = GetNumActiveClientsMsg

@typing_extensions.final
class StopClientPopulationMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the client population of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopClientPopulationMsg = StopClientPopulationMsg

@typing_extensions.final
class StopClientManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the client manager of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopClientManagerMsg = StopClientManagerMsg

@typing_extensions.final
class StartClientManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the client manager of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartClientManagerMsg = StartClientManagerMsg

@typing_extensions.final
class StopTrafficManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop all traffic managers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopTrafficManagersMsg = StopTrafficManagersMsg

@typing_extensions.final
class StopTrafficManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific traffic manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopTrafficManagerMsg = StopTrafficManagerMsg

@typing_extensions.final
class StartTrafficManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific traffic manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartTrafficManagerMsg = StartTrafficManagerMsg

@typing_extensions.final
class CleanAllExecutionsMsg(google.protobuf.message.Message):
    """Message that the client sends to clean all executions"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CleanAllExecutionsMsg = CleanAllExecutionsMsg

@typing_extensions.final
class StopAllExecutionsMsg(google.protobuf.message.Message):
    """Message that the client sends to stop all executions"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopAllExecutionsMsg = StopAllExecutionsMsg

@typing_extensions.final
class StopExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends to stop a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopExecutionMsg = StopExecutionMsg

@typing_extensions.final
class CleanExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends to clean a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CleanExecutionMsg = CleanExecutionMsg

@typing_extensions.final
class StopAllExecutionsOfEmulationMsg(google.protobuf.message.Message):
    """Message that the client sends to stop all executions of a given emulation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation"]) -> None: ...

global___StopAllExecutionsOfEmulationMsg = StopAllExecutionsOfEmulationMsg

@typing_extensions.final
class CleanAllExecutionsOfEmulationMsg(google.protobuf.message.Message):
    """Message that the client sends to clean all executions of a given emulation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation"]) -> None: ...

global___CleanAllExecutionsOfEmulationMsg = CleanAllExecutionsOfEmulationMsg

@typing_extensions.final
class GetCsleLogFilesMsg(google.protobuf.message.Message):
    """Message that the client sends to get the log file names in the /var/log/csle directory"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCsleLogFilesMsg = GetCsleLogFilesMsg

@typing_extensions.final
class GetLogFileMsg(google.protobuf.message.Message):
    """Message that the client sends to get a given log file"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetLogFileMsg = GetLogFileMsg

@typing_extensions.final
class StartContainersInExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start containers of a given emulation execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartContainersInExecutionMsg = StartContainersInExecutionMsg

@typing_extensions.final
class AttachContainersToNetworksInExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to attach containers of a given emulation execution to networks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___AttachContainersToNetworksInExecutionMsg = AttachContainersToNetworksInExecutionMsg

@typing_extensions.final
class InstallLibrariesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to install CSLE libraries on containers that are part of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___InstallLibrariesMsg = InstallLibrariesMsg

@typing_extensions.final
class ApplyKafkaConfigMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the kafka config to a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyKafkaConfigMsg = ApplyKafkaConfigMsg

@typing_extensions.final
class StartSdnControllerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply start the SDN controller of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSdnControllerMsg = StartSdnControllerMsg

@typing_extensions.final
class ApplyResouceConstraintsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply resource constraints to containers of an emulation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyResouceConstraintsMsg = ApplyResouceConstraintsMsg

@typing_extensions.final
class CreateOvsSwitchesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create OvsSwitches"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateOvsSwitchesMsg = CreateOvsSwitchesMsg

@typing_extensions.final
class PingExecutionMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to test ping between containers in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___PingExecutionMsg = PingExecutionMsg

@typing_extensions.final
class ConfigureOvsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to configure OVS on an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ConfigureOvsMsg = ConfigureOvsMsg

@typing_extensions.final
class StartSdnControllerMonitorMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the SDN controller monitor in an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSdnControllerMonitorMsg = StartSdnControllerMonitorMsg

@typing_extensions.final
class CreateUsersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create users of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateUsersMsg = CreateUsersMsg

@typing_extensions.final
class CreateVulnsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create vulnerabilities of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateVulnsMsg = CreateVulnsMsg

@typing_extensions.final
class CreateFlagsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create flags of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateFlagsMsg = CreateFlagsMsg

@typing_extensions.final
class CreateTopologyMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to create the topology of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___CreateTopologyMsg = CreateTopologyMsg

@typing_extensions.final
class StartTrafficManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start traffic managers of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartTrafficManagersMsg = StartTrafficManagersMsg

@typing_extensions.final
class StartTrafficGeneratorsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start traffic generators of a given execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartTrafficGeneratorsMsg = StartTrafficGeneratorsMsg

@typing_extensions.final
class StartClientPopulationMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the client population of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartClientPopulationMsg = StartClientPopulationMsg

@typing_extensions.final
class StartKafkaClientProducerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the client Kafka producer of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartKafkaClientProducerMsg = StartKafkaClientProducerMsg

@typing_extensions.final
class StopKafkaClientProducerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the client Kafka producer of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StopKafkaClientProducerMsg = StopKafkaClientProducerMsg

@typing_extensions.final
class StartSnortIdsesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Snort IDSes of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortIdsesMsg = StartSnortIdsesMsg

@typing_extensions.final
class StartSnortIdsesMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Snort IDSes Monitor threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartSnortIdsesMonitorThreadsMsg = StartSnortIdsesMonitorThreadsMsg

@typing_extensions.final
class StartOSSECIdsesMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the OSSEC IDSes of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIdsesMsg = StartOSSECIdsesMsg

@typing_extensions.final
class StartOSSECIdsesMonitorThreadsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the OSSEC IDSes monitor threads of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartOSSECIdsesMonitorThreadsMsg = StartOSSECIdsesMonitorThreadsMsg

@typing_extensions.final
class StartElkStackMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the ELK stack of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartElkStackMsg = StartElkStackMsg

@typing_extensions.final
class StartHostManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the Host managers of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartHostManagersMsg = StartHostManagersMsg

@typing_extensions.final
class ApplyFileBeatConfigsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the filebeat configurations of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyFileBeatConfigsMsg = ApplyFileBeatConfigsMsg

@typing_extensions.final
class ApplyPacketBeatConfigsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the packetbeat configurations of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyPacketBeatConfigsMsg = ApplyPacketBeatConfigsMsg

@typing_extensions.final
class ApplyMetricBeatConfigsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the metricbeat configurations of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyMetricBeatConfigsMsg = ApplyMetricBeatConfigsMsg

@typing_extensions.final
class ApplyHeartBeatConfigsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to apply the heartbeat configurations of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___ApplyHeartBeatConfigsMsg = ApplyHeartBeatConfigsMsg

@typing_extensions.final
class StartFileBeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the filebeats of an execution of a specific execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartFileBeatsMsg = StartFileBeatsMsg

@typing_extensions.final
class StartPacketBeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the packetbeats of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartPacketBeatsMsg = StartPacketBeatsMsg

@typing_extensions.final
class StartMetricBeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the metricbeats of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartMetricBeatsMsg = StartMetricBeatsMsg

@typing_extensions.final
class StartHeartBeatsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the heartbeats of an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    INITIALSTART_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    initialStart: builtins.bool
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        initialStart: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "initialStart", b"initialStart", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartHeartBeatsMsg = StartHeartBeatsMsg

@typing_extensions.final
class GetDockerStatsManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the docker statsmanager logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDockerStatsManagerLogsMsg = GetDockerStatsManagerLogsMsg

@typing_extensions.final
class GetPrometheusLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the Prometheus logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetPrometheusLogsMsg = GetPrometheusLogsMsg

@typing_extensions.final
class GetNodeExporterLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the Node exporter logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetNodeExporterLogsMsg = GetNodeExporterLogsMsg

@typing_extensions.final
class GetCAdvisorLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the cAdvisor logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCAdvisorLogsMsg = GetCAdvisorLogsMsg

@typing_extensions.final
class GetPgAdminLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the pgAdming logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetPgAdminLogsMsg = GetPgAdminLogsMsg

@typing_extensions.final
class GetGrafanaLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the grafana logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetGrafanaLogsMsg = GetGrafanaLogsMsg

@typing_extensions.final
class GetNginxLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the nginx logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetNginxLogsMsg = GetNginxLogsMsg

@typing_extensions.final
class GetDockerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the docker logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDockerLogsMsg = GetDockerLogsMsg

@typing_extensions.final
class GetPostgreSQLLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the posgresql logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetPostgreSQLLogsMsg = GetPostgreSQLLogsMsg

@typing_extensions.final
class GetFlaskLogsMsg(google.protobuf.message.Message):
    """Message that the client sends to get the flask logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetFlaskLogsMsg = GetFlaskLogsMsg

@typing_extensions.final
class LogsDTO(google.protobuf.message.Message):
    """Message that the server returns after a request for logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logs", b"logs"]) -> None: ...

global___LogsDTO = LogsDTO

@typing_extensions.final
class OperationOutcomeDTO(google.protobuf.message.Message):
    """Message that the server returns after executing an operation requested by a client"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTCOME_FIELD_NUMBER: builtins.int
    outcome: builtins.bool
    def __init__(
        self,
        *,
        outcome: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outcome", b"outcome"]) -> None: ...

global___OperationOutcomeDTO = OperationOutcomeDTO

@typing_extensions.final
class GetNodeStatusMsg(google.protobuf.message.Message):
    """Message that the client sends to get the status of the node"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetNodeStatusMsg = GetNodeStatusMsg

@typing_extensions.final
class NodeStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when requested by the client, contains info about node's status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_FIELD_NUMBER: builtins.int
    LEADER_FIELD_NUMBER: builtins.int
    CADVISORRUNNING_FIELD_NUMBER: builtins.int
    PROMETHEUSRUNNING_FIELD_NUMBER: builtins.int
    GRAFANARUNNING_FIELD_NUMBER: builtins.int
    PGADMINRUNNING_FIELD_NUMBER: builtins.int
    NGINXRUNNING_FIELD_NUMBER: builtins.int
    FLASKRUNNING_FIELD_NUMBER: builtins.int
    DOCKERSTATSMANAGERRUNNING_FIELD_NUMBER: builtins.int
    NODEEXPORTERRUNNING_FIELD_NUMBER: builtins.int
    POSTGRESQLRUNNING_FIELD_NUMBER: builtins.int
    DOCKERENGINERUNNING_FIELD_NUMBER: builtins.int
    ip: builtins.str
    leader: builtins.bool
    cAdvisorRunning: builtins.bool
    prometheusRunning: builtins.bool
    grafanaRunning: builtins.bool
    pgAdminRunning: builtins.bool
    nginxRunning: builtins.bool
    flaskRunning: builtins.bool
    dockerStatsManagerRunning: builtins.bool
    nodeExporterRunning: builtins.bool
    postgreSQLRunning: builtins.bool
    dockerEngineRunning: builtins.bool
    def __init__(
        self,
        *,
        ip: builtins.str = ...,
        leader: builtins.bool = ...,
        cAdvisorRunning: builtins.bool = ...,
        prometheusRunning: builtins.bool = ...,
        grafanaRunning: builtins.bool = ...,
        pgAdminRunning: builtins.bool = ...,
        nginxRunning: builtins.bool = ...,
        flaskRunning: builtins.bool = ...,
        dockerStatsManagerRunning: builtins.bool = ...,
        nodeExporterRunning: builtins.bool = ...,
        postgreSQLRunning: builtins.bool = ...,
        dockerEngineRunning: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cAdvisorRunning", b"cAdvisorRunning", "dockerEngineRunning", b"dockerEngineRunning", "dockerStatsManagerRunning", b"dockerStatsManagerRunning", "flaskRunning", b"flaskRunning", "grafanaRunning", b"grafanaRunning", "ip", b"ip", "leader", b"leader", "nginxRunning", b"nginxRunning", "nodeExporterRunning", b"nodeExporterRunning", "pgAdminRunning", b"pgAdminRunning", "postgreSQLRunning", b"postgreSQLRunning", "prometheusRunning", b"prometheusRunning"]) -> None: ...

global___NodeStatusDTO = NodeStatusDTO

@typing_extensions.final
class ServiceStatusDTO(google.protobuf.message.Message):
    """Message that the server returns when changing the status of a service"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_FIELD_NUMBER: builtins.int
    running: builtins.bool
    def __init__(
        self,
        *,
        running: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["running", b"running"]) -> None: ...

global___ServiceStatusDTO = ServiceStatusDTO

@typing_extensions.final
class StartPostgreSQLMsg(google.protobuf.message.Message):
    """Message that the client sends to start PostgreSQL"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartPostgreSQLMsg = StartPostgreSQLMsg

@typing_extensions.final
class StartCAdvisorMsg(google.protobuf.message.Message):
    """Message that the client sends to start cAdvisor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartCAdvisorMsg = StartCAdvisorMsg

@typing_extensions.final
class StartNodeExporterMsg(google.protobuf.message.Message):
    """Message that the client sends to start node exporter"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartNodeExporterMsg = StartNodeExporterMsg

@typing_extensions.final
class StartGrafanaMsg(google.protobuf.message.Message):
    """Message that the client sends to start grafana"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartGrafanaMsg = StartGrafanaMsg

@typing_extensions.final
class StartPrometheusMsg(google.protobuf.message.Message):
    """Message that the client sends to start Prometheus"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartPrometheusMsg = StartPrometheusMsg

@typing_extensions.final
class StartPgAdminMsg(google.protobuf.message.Message):
    """Message that the client sends to start pgAdmin"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartPgAdminMsg = StartPgAdminMsg

@typing_extensions.final
class StartNginxMsg(google.protobuf.message.Message):
    """Message that the client sends to start nginx"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartNginxMsg = StartNginxMsg

@typing_extensions.final
class StartFlaskMsg(google.protobuf.message.Message):
    """Message that the client sends to start flask"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartFlaskMsg = StartFlaskMsg

@typing_extensions.final
class StartDockerStatsManagerMsg(google.protobuf.message.Message):
    """Message that the client sends to start dockerStatsManager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartDockerStatsManagerMsg = StartDockerStatsManagerMsg

@typing_extensions.final
class StartDockerStatsManagerThreadMsg(google.protobuf.message.Message):
    """Message that the client sends to start a dockerStatsManager thread for an execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___StartDockerStatsManagerThreadMsg = StartDockerStatsManagerThreadMsg

@typing_extensions.final
class StartDockerEngineMsg(google.protobuf.message.Message):
    """Message that the client sends to start the docker engine"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartDockerEngineMsg = StartDockerEngineMsg

@typing_extensions.final
class StopPostgreSQLMsg(google.protobuf.message.Message):
    """Message that the client sends to stop PostgreSQL"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopPostgreSQLMsg = StopPostgreSQLMsg

@typing_extensions.final
class StopCAdvisorMsg(google.protobuf.message.Message):
    """Message that the client sends to stop cAdvisor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopCAdvisorMsg = StopCAdvisorMsg

@typing_extensions.final
class StopNodeExporterMsg(google.protobuf.message.Message):
    """Message that the client sends to stop node exporter"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopNodeExporterMsg = StopNodeExporterMsg

@typing_extensions.final
class StopGrafanaMsg(google.protobuf.message.Message):
    """Message that the client sends to stop grafana"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopGrafanaMsg = StopGrafanaMsg

@typing_extensions.final
class StopPrometheusMsg(google.protobuf.message.Message):
    """Message that the client sends to stop Prometheus"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopPrometheusMsg = StopPrometheusMsg

@typing_extensions.final
class StopPgAdminMsg(google.protobuf.message.Message):
    """Message that the client sends to stop pgAdmin"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopPgAdminMsg = StopPgAdminMsg

@typing_extensions.final
class StopNginxMsg(google.protobuf.message.Message):
    """Message that the client sends to stop nginx"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopNginxMsg = StopNginxMsg

@typing_extensions.final
class StopFlaskMsg(google.protobuf.message.Message):
    """Message that the client sends to stop flask"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopFlaskMsg = StopFlaskMsg

@typing_extensions.final
class StopDockerStatsManagerMsg(google.protobuf.message.Message):
    """Message that the client sends to stop dockerStatsManager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopDockerStatsManagerMsg = StopDockerStatsManagerMsg

@typing_extensions.final
class StopDockerEngineMsg(google.protobuf.message.Message):
    """Message that the client sends to stop the docker engine"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopDockerEngineMsg = StopDockerEngineMsg

@typing_extensions.final
class Start5GCoreManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start 5G core managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCoreManagersMsg = Start5GCoreManagersMsg

@typing_extensions.final
class Stop5GCoreManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop 5G core managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCoreManagersMsg = Stop5GCoreManagersMsg

@typing_extensions.final
class Start5GCoreManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G core manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCoreManagerMsg = Start5GCoreManagerMsg

@typing_extensions.final
class Stop5GCoreManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G core manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCoreManagerMsg = Stop5GCoreManagerMsg

@typing_extensions.final
class Stop5GCoreMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G core"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCoreMsg = Stop5GCoreMsg

@typing_extensions.final
class Stop5GCoresMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the 5G cores"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCoresMsg = Stop5GCoresMsg

@typing_extensions.final
class Start5GCoreMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G core"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCoreMsg = Start5GCoreMsg

@typing_extensions.final
class Start5GCoresMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the 5G cores"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCoresMsg = Start5GCoresMsg

@typing_extensions.final
class Init5GCoreMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to initialize a specific 5G core"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Init5GCoreMsg = Init5GCoreMsg

@typing_extensions.final
class Init5GCoresMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to initialize the 5G cores"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Init5GCoresMsg = Init5GCoresMsg

@typing_extensions.final
class Start5GCUManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start 5G cu managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCUManagersMsg = Start5GCUManagersMsg

@typing_extensions.final
class Stop5GCUManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop 5G cu managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCUManagersMsg = Stop5GCUManagersMsg

@typing_extensions.final
class Start5GCUManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G cu manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCUManagerMsg = Start5GCUManagerMsg

@typing_extensions.final
class Stop5GCUManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G cu manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCUManagerMsg = Stop5GCUManagerMsg

@typing_extensions.final
class Stop5GCUMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G cu"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCUMsg = Stop5GCUMsg

@typing_extensions.final
class Stop5GCUsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the 5G cus"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GCUsMsg = Stop5GCUsMsg

@typing_extensions.final
class Start5GCUMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G cu"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCUMsg = Start5GCUMsg

@typing_extensions.final
class Start5GCUsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the 5G cus"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GCUsMsg = Start5GCUsMsg

@typing_extensions.final
class Start5GDUManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start 5G du managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GDUManagersMsg = Start5GDUManagersMsg

@typing_extensions.final
class Stop5GDUManagersMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop 5G du managers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GDUManagersMsg = Stop5GDUManagersMsg

@typing_extensions.final
class Start5GDUManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G du manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GDUManagerMsg = Start5GDUManagerMsg

@typing_extensions.final
class Stop5GDUManagerMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G du manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GDUManagerMsg = Stop5GDUManagerMsg

@typing_extensions.final
class Stop5GDUMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G du"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GDUMsg = Stop5GDUMsg

@typing_extensions.final
class Stop5GDUsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the 5G dus"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GDUsMsg = Stop5GDUsMsg

@typing_extensions.final
class Start5GDUMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G du"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GDUMsg = Start5GDUMsg

@typing_extensions.final
class Start5GDUsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the 5G dus"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GDUsMsg = Start5GDUsMsg

@typing_extensions.final
class Stop5GUEMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop a specific 5G UE"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GUEMsg = Stop5GUEMsg

@typing_extensions.final
class Stop5GUEsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to stop the 5G UEs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Stop5GUEsMsg = Stop5GUEsMsg

@typing_extensions.final
class Start5GUEMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start a specific 5G UE"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GUEMsg = Start5GUEMsg

@typing_extensions.final
class Start5GUEsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to start the 5G UEs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Start5GUEsMsg = Start5GUEsMsg

@typing_extensions.final
class Init5GUEMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to initialize a specific 5G UE"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Init5GUEMsg = Init5GUEMsg

@typing_extensions.final
class Init5GUEsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to initialize the 5G UEs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Init5GUEsMsg = Init5GUEsMsg

@typing_extensions.final
class Get5GCoreManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the 5G core managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GCoreManagersInfoMsg = Get5GCoreManagersInfoMsg

@typing_extensions.final
class Get5GCUManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the 5G CU managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GCUManagersInfoMsg = Get5GCUManagersInfoMsg

@typing_extensions.final
class Get5GDUManagersInfoMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get the 5G DU managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GDUManagersInfoMsg = Get5GDUManagersInfoMsg

@typing_extensions.final
class FiveGCoreInfoDTO(google.protobuf.message.Message):
    """Info DTO for the 5G Core"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONGO_RUNNING_FIELD_NUMBER: builtins.int
    MME_RUNNING_FIELD_NUMBER: builtins.int
    SGWC_RUNNING_FIELD_NUMBER: builtins.int
    SMF_RUNNING_FIELD_NUMBER: builtins.int
    AMF_RUNNING_FIELD_NUMBER: builtins.int
    SGWU_RUNNING_FIELD_NUMBER: builtins.int
    UPF_RUNNING_FIELD_NUMBER: builtins.int
    HSS_RUNNING_FIELD_NUMBER: builtins.int
    PCRF_RUNNING_FIELD_NUMBER: builtins.int
    NRF_RUNNING_FIELD_NUMBER: builtins.int
    SCP_RUNNING_FIELD_NUMBER: builtins.int
    SEPP_RUNNING_FIELD_NUMBER: builtins.int
    AUSF_RUNNING_FIELD_NUMBER: builtins.int
    UDM_RUNNING_FIELD_NUMBER: builtins.int
    PCF_RUNNING_FIELD_NUMBER: builtins.int
    NSSF_RUNNING_FIELD_NUMBER: builtins.int
    BSF_RUNNING_FIELD_NUMBER: builtins.int
    UDR_RUNNING_FIELD_NUMBER: builtins.int
    WEBUI_RUNNING_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    mongo_running: builtins.bool
    mme_running: builtins.bool
    sgwc_running: builtins.bool
    smf_running: builtins.bool
    amf_running: builtins.bool
    sgwu_running: builtins.bool
    upf_running: builtins.bool
    hss_running: builtins.bool
    pcrf_running: builtins.bool
    nrf_running: builtins.bool
    scp_running: builtins.bool
    sepp_running: builtins.bool
    ausf_running: builtins.bool
    udm_running: builtins.bool
    pcf_running: builtins.bool
    nssf_running: builtins.bool
    bsf_running: builtins.bool
    udr_running: builtins.bool
    webui_running: builtins.bool
    ip: builtins.str
    def __init__(
        self,
        *,
        mongo_running: builtins.bool = ...,
        mme_running: builtins.bool = ...,
        sgwc_running: builtins.bool = ...,
        smf_running: builtins.bool = ...,
        amf_running: builtins.bool = ...,
        sgwu_running: builtins.bool = ...,
        upf_running: builtins.bool = ...,
        hss_running: builtins.bool = ...,
        pcrf_running: builtins.bool = ...,
        nrf_running: builtins.bool = ...,
        scp_running: builtins.bool = ...,
        sepp_running: builtins.bool = ...,
        ausf_running: builtins.bool = ...,
        udm_running: builtins.bool = ...,
        pcf_running: builtins.bool = ...,
        nssf_running: builtins.bool = ...,
        bsf_running: builtins.bool = ...,
        udr_running: builtins.bool = ...,
        webui_running: builtins.bool = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amf_running", b"amf_running", "ausf_running", b"ausf_running", "bsf_running", b"bsf_running", "hss_running", b"hss_running", "ip", b"ip", "mme_running", b"mme_running", "mongo_running", b"mongo_running", "nrf_running", b"nrf_running", "nssf_running", b"nssf_running", "pcf_running", b"pcf_running", "pcrf_running", b"pcrf_running", "scp_running", b"scp_running", "sepp_running", b"sepp_running", "sgwc_running", b"sgwc_running", "sgwu_running", b"sgwu_running", "smf_running", b"smf_running", "udm_running", b"udm_running", "udr_running", b"udr_running", "upf_running", b"upf_running", "webui_running", b"webui_running"]) -> None: ...

global___FiveGCoreInfoDTO = FiveGCoreInfoDTO

@typing_extensions.final
class FiveGCUInfoDTO(google.protobuf.message.Message):
    """Info DTO for the 5G CU"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CU_RUNNING_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    cu_running: builtins.bool
    ip: builtins.str
    def __init__(
        self,
        *,
        cu_running: builtins.bool = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cu_running", b"cu_running", "ip", b"ip"]) -> None: ...

global___FiveGCUInfoDTO = FiveGCUInfoDTO

@typing_extensions.final
class FiveGDUInfoDTO(google.protobuf.message.Message):
    """Info DTO for the 5G DU"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DU_RUNNING_FIELD_NUMBER: builtins.int
    UE_RUNNING_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    du_running: builtins.bool
    ue_running: builtins.bool
    ip: builtins.str
    def __init__(
        self,
        *,
        du_running: builtins.bool = ...,
        ue_running: builtins.bool = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["du_running", b"du_running", "ip", b"ip", "ue_running", b"ue_running"]) -> None: ...

global___FiveGDUInfoDTO = FiveGDUInfoDTO

@typing_extensions.final
class FiveGCoreManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the 5G Core managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    FIVEGCOREMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    FIVEGCOREMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def fiveGCoreManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def fiveGCoreManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FiveGCoreInfoDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        fiveGCoreManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        fiveGCoreManagersStatuses: collections.abc.Iterable[global___FiveGCoreInfoDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "fiveGCoreManagersRunning", b"fiveGCoreManagersRunning", "fiveGCoreManagersStatuses", b"fiveGCoreManagersStatuses", "ips", b"ips", "ports", b"ports"]) -> None: ...

global___FiveGCoreManagersInfoDTO = FiveGCoreManagersInfoDTO

@typing_extensions.final
class FiveGCUManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the 5G CU managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    FIVEGCUMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    FIVEGCUMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def fiveGCUManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def fiveGCUManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FiveGCUInfoDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        fiveGCUManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        fiveGCUManagersStatuses: collections.abc.Iterable[global___FiveGCUInfoDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "fiveGCUManagersRunning", b"fiveGCUManagersRunning", "fiveGCUManagersStatuses", b"fiveGCUManagersStatuses", "ips", b"ips", "ports", b"ports"]) -> None: ...

global___FiveGCUManagersInfoDTO = FiveGCUManagersInfoDTO

@typing_extensions.final
class FiveGDUManagersInfoDTO(google.protobuf.message.Message):
    """Message that the server returns when requested for the 5G DU managers info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    EMULATIONNAME_FIELD_NUMBER: builtins.int
    EXECUTIONID_FIELD_NUMBER: builtins.int
    FIVEGDUMANAGERSRUNNING_FIELD_NUMBER: builtins.int
    FIVEGDUMANAGERSSTATUSES_FIELD_NUMBER: builtins.int
    @property
    def ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    emulationName: builtins.str
    executionId: builtins.int
    @property
    def fiveGDUManagersRunning(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    @property
    def fiveGDUManagersStatuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FiveGDUInfoDTO]: ...
    def __init__(
        self,
        *,
        ips: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
        emulationName: builtins.str = ...,
        executionId: builtins.int = ...,
        fiveGDUManagersRunning: collections.abc.Iterable[builtins.bool] | None = ...,
        fiveGDUManagersStatuses: collections.abc.Iterable[global___FiveGDUInfoDTO] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulationName", b"emulationName", "executionId", b"executionId", "fiveGDUManagersRunning", b"fiveGDUManagersRunning", "fiveGDUManagersStatuses", b"fiveGDUManagersStatuses", "ips", b"ips", "ports", b"ports"]) -> None: ...

global___FiveGDUManagersInfoDTO = FiveGDUManagersInfoDTO

@typing_extensions.final
class Get5GCoreManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G core manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GCoreManagerLogsMsg = Get5GCoreManagerLogsMsg

@typing_extensions.final
class Get5GCUManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G CU manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GCUManagerLogsMsg = Get5GCUManagerLogsMsg

@typing_extensions.final
class Get5GDUManagerLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G DU manager"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GDUManagerLogsMsg = Get5GDUManagerLogsMsg

@typing_extensions.final
class Get5GCoreLogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G core"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GCoreLogsMsg = Get5GCoreLogsMsg

@typing_extensions.final
class Get5GCULogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G CU"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GCULogsMsg = Get5GCULogsMsg

@typing_extensions.final
class Get5GDULogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G DU"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GDULogsMsg = Get5GDULogsMsg

@typing_extensions.final
class Get5GUELogsMsg(google.protobuf.message.Message):
    """Message that the client sends when requesting to get logs of a specific 5G UE"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    IPFIRSTOCTET_FIELD_NUMBER: builtins.int
    CONTAINERIP_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    ipFirstOctet: builtins.int
    containerIp: builtins.str
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        ipFirstOctet: builtins.int = ...,
        containerIp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerIp", b"containerIp", "emulation", b"emulation", "ipFirstOctet", b"ipFirstOctet"]) -> None: ...

global___Get5GUELogsMsg = Get5GUELogsMsg
